% Auto-generated chapter 11 for muslim
% Hadiths in this chapter: 135

\hadithdefcmd{muslim}{2123}{وَحَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، فُضَيْلُ بْنُ حُسَيْنٍ وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ كِلاَهُمَا عَنْ بِشْرٍ، - قَالَ أَبُو كَامِلٍ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، - حَدَّثَنَا عُمَارَةُ بْنُ غَزِيَّةَ، حَدَّثَنَا يَحْيَى، بْنُ عُمَارَةَ قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقِّنُوا مَوْتَاكُمْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{2123}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying:Exhort to recite" There is no god but Allah" to those of you who are dying}}
\hadithdefcmd{muslim}{2124}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ يَعْنِي الدَّرَاوَرْدِيَّ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، جَمِيعًا بِهَذَا الإِسْنَادِ ‏.‏\hadithno{2124}\hadithtrans{This hadith has been narrated by Sulaiman b. Bilal with the same chain of transmitters}}
\hadithdefcmd{muslim}{2125}{وَحَدَّثَنَا أَبُو بَكْرٍ، وَعُثْمَانُ، ابْنَا أَبِي شَيْبَةَ ح وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، قَالُوا جَمِيعًا حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقِّنُوا مَوْتَاكُمْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{2125}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Exhort to recite" There is no god but Allah" to those of you who are dying}}
\hadithdefcmd{muslim}{2126}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ جَمِيعًا عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، - قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ، - أَخْبَرَنِي سَعْدُ بْنُ سَعِيدٍ، عَنْ عُمَرَ بْنِ كَثِيرِ بْنِ أَفْلَحَ، عَنِ ابْنِ، سَفِينَةَ عَنْ أُمِّ سَلَمَةَ، أَنَّهَا قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَا مِنْ مُسْلِمٍ تُصِيبُهُ مُصِيبَةٌ فَيَقُولُ مَا أَمَرَهُ اللَّهُ إِنَّا لِلَّهِ وَإِنَّا إِلَيْهِ رَاجِعُونَ اللَّهُمَّ أْجُرْنِي فِي مُصِيبَتِي وَأَخْلِفْ لِي خَيْرًا مِنْهَا ‏.‏ إِلاَّ أَخْلَفَ اللَّهُ لَهُ خَيْرًا مِنْهَا ‏"‏ ‏.‏ قَالَتْ فَلَمَّا مَاتَ أَبُو سَلَمَةَ قُلْتُ أَىُّ الْمُسْلِمِينَ خَيْرٌ مِنْ أَبِي سَلَمَةَ أَوَّلُ بَيْتٍ هَاجَرَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ ثُمَّ إِنِّي قُلْتُهَا فَأَخْلَفَ اللَّهُ لِي رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ أَرْسَلَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم حَاطِبَ بْنَ أَبِي بَلْتَعَةَ يَخْطُبُنِي لَهُ فَقُلْتُ إِنَّ لِي بِنْتًا وَأَنَا غَيُورٌ ‏.‏ فَقَالَ ‏"‏ أَمَّا ابْنَتُهَا فَنَدْعُو اللَّهَ أَنْ يُغْنِيَهَا عَنْهَا وَأَدْعُو اللَّهَ أَنْ يَذْهَبَ بِالْغَيْرَةِ ‏"‏ ‏.‏\hadithno{2126}\hadithtrans{Umm Salama reported Allah's Messenger (ﷺ) as saying:If any Muslim who suffers some calamity says, what Allah has commanded him," We belong to Allah and to Him shall we return; O Allah, reward me for my affliction and give me something better than it in exchange for it," Allah will give him something better than it in exchange. When Abu Salama died she said: What Muslim is better than Abu Salama whose family was the first to emigrate to the Messenger of Allah (ﷺ). I then said the words, and Allah gave me God's Messenger (ﷺ) in exchange. She said: The Messenger of Allah (ﷺ) sent Hatib b. Abu Balta'a to deliver me the message of marriage with him. I said to him: I have a daughter (as my dependant) and I am of jealous temperament. He (the Holy Prophet) said: So far as her daughter is concerned, we would supplicate Allah, that He may free her (of her responsibility) and I would also supplicate Allah to do away with (her) jealous (temperament)}}
\hadithdefcmd{muslim}{2127}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ سَعْدِ بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي عُمَرُ بْنُ كَثِيرِ بْنِ أَفْلَحَ، قَالَ سَمِعْتُ ابْنَ سَفِينَةَ، يُحَدِّثُ أَنَّهُ سَمِعَ أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ عَبْدٍ تُصِيبُهُ مُصِيبَةٌ فَيَقُولُ إِنَّا لِلَّهِ وَإِنَّا إِلَيْهِ رَاجِعُونَ اللَّهُمَّ أْجُرْنِي فِي مُصِيبَتِي وَأَخْلِفْ لِي خَيْرًا مِنْهَا إِلاَّ أَجَرَهُ اللَّهُ فِي مُصِيبَتِهِ وَأَخْلَفَ لَهُ خَيْرًا مِنْهَا ‏"‏ ‏.‏ قَالَتْ فَلَمَّا تُوُفِّيَ أَبُو سَلَمَةَ قُلْتُ كَمَا أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْلَفَ اللَّهُ لِي خَيْرًا مِنْهُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2127}\hadithtrans{Umm Salama, the wife of the Messenger of Allah (ﷺ), reported Allah's Messenger (ﷺ) as saying:If any servant (of Allah) who suffers a calamity says:" We belong to Allah and to Him shall we return; O Allah, reward me for my affliction and give me something better than it in exchange for it," ' Allah will give him reward for affliction, and would give him something better than it in exchange. She (Umm Salama) said: When Abu Salama died. I uttered (these very words) as I was commanded (to do) by the Messenger of Allah (ﷺ). So Allah gave me better in exchange than him. i. e. (I was taken as the wife of) the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2128}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سَعْدُ بْنُ سَعِيدٍ، أَخْبَرَنِي عُمَرُ، - يَعْنِي ابْنَ كَثِيرٍ - عَنِ ابْنِ سَفِينَةَ، مَوْلَى أُمِّ سَلَمَةَ عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ بِمِثْلِ حَدِيثِ أَبِي أُسَامَةَ وَزَادَ قَالَتْ فَلَمَّا تُوُفِّيَ أَبُو سَلَمَةَ قُلْتُ مَنْ خَيْرٌ مِنْ أَبِي سَلَمَةَ صَاحِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ عَزَمَ اللَّهُ لِي فَقُلْتُهَا ‏.‏ قَالَتْ فَتَزَوَّجْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2128}\hadithtrans{Umm Salama, the wife of the Messenger of Allah (way peace be upon him), reported Allah's Messenger (ﷺ) saying like the hadith transmitted by Abu Usama, but with this addition that she said:" When Abu Salama died I said: Who is better than Abu Salama, the Companion of the Messenger of Allah (ﷺ), and Allah decided for me and I said (these words contained in the supplication mentioned above) and I was married to the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2129}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا حَضَرْتُمُ الْمَرِيضَ أَوِ الْمَيِّتَ فَقُولُوا خَيْرًا فَإِنَّ الْمَلاَئِكَةَ يُؤَمِّنُونَ عَلَى مَا تَقُولُونَ ‏"‏ ‏.‏ قَالَتْ فَلَمَّا مَاتَ أَبُو سَلَمَةَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سَلَمَةَ قَدْ مَاتَ قَالَ ‏"‏ قُولِي اللَّهُمَّ اغْفِرْ لِي وَلَهُ وَأَعْقِبْنِي مِنْهُ عُقْبَى حَسَنَةً ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ فَأَعْقَبَنِي اللَّهُ مَنْ هُوَ خَيْرٌ لِي مِنْهُ مُحَمَّدًا صلى الله عليه وسلم ‏.‏\hadithno{2129}\hadithtrans{Umm Salama reported Allah's Messenger (ﷺ) as saying:Whenever you visit the sick or the dead, supplicate for good because angels say" Amen" to whatever you say. She added: When Abu Salama died, I went to the Messenger of Allah (ﷺ) and said: Messenger of Allah, Abu Salama has died. He told me to recite:" O Allah! forgive me and him (Abu Salama) and give me a better substitute than he." So I said (this), and Allah gave me in exchange Muhammad, who is better for me than him (Abu Salama)}}
\hadithdefcmd{muslim}{2130}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى أَبِي سَلَمَةَ وَقَدْ شَقَّ بَصَرُهُ فَأَغْمَضَهُ ثُمَّ قَالَ ‏"‏ إِنَّ الرُّوحَ إِذَا قُبِضَ تَبِعَهُ الْبَصَرُ ‏"‏ ‏.‏ فَضَجَّ نَاسٌ مِنْ أَهْلِهِ فَقَالَ ‏"‏ لاَ تَدْعُوا عَلَى أَنْفُسِكُمْ إِلاَّ بِخَيْرٍ فَإِنَّ الْمَلاَئِكَةَ يُؤَمِّنُونَ عَلَى مَا تَقُولُونَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لأَبِي سَلَمَةَ وَارْفَعْ دَرَجَتَهُ فِي الْمَهْدِيِّينَ وَاخْلُفْهُ فِي عَقِبِهِ فِي الْغَابِرِينَ وَاغْفِرْ لَنَا وَلَهُ يَا رَبَّ الْعَالَمِينَ وَافْسَحْ لَهُ فِي قَبْرِهِ ‏.‏ وَنَوِّرْ لَهُ فِيهِ ‏"‏ ‏.‏\hadithno{2130}\hadithtrans{Umm Salama reported:The Messenger of Allah (may peace be upon came to Abu Salama (as he died). His eyes were fixedly open. He closed them, and then said: When the soul is taken away the sight follows it. Some of the people of his family wept and wailed. So he said: Do not supplicate for yourselves anything but good, for angels say" Amen" to what you say. He then said: O Allah, forgive Abu Salama, raise his degree among those who are rightly guided, grant him a successor in his descendants who remain. Forgive us and him, O Lord of the Universe, and make his grave spacious, and grant him light in it}}
\hadithdefcmd{muslim}{2131}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْقَطَّانُ الْوَاسِطِيُّ، حَدَّثَنَا الْمُثَنَّى بْنُ مُعَاذِ بْنِ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ الْحَسَنِ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، بِهَذَا الإِسْنَادِ نَحْوَهُ غَيْرَ أَنَّهُ قَالَ ‏"‏ وَاخْلُفْهُ فِي تَرِكَتِهِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ اللَّهُمَّ أَوْسِعْ لَهُ فِي قَبْرِهِ ‏"‏ ‏.‏ وَلَمْ يَقُلِ ‏"‏ افْسَحْ لَهُ ‏"‏ ‏.‏ وَزَادَ قَالَ خَالِدٌ الْحَذَّاءُ وَدَعْوَةٌ أُخْرَى سَابِعَةٌ نَسِيتُهَا ‏.‏\hadithno{2131}\hadithtrans{This hadith has been narrated by Khalid al Hadhdha' with the same chain of transmitters but with this alteration that he said:(O Allah! ) let Thee be the caretaker of what is left by him, and he said: Grant him expansion of the grave, but he did not say: Make his grave spacious. Khalid said: He supplicated for the seventh (thing too) which I have forgotten}}
\hadithdefcmd{muslim}{2132}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنِ الْعَلاَءِ بْنِ، يَعْقُوبَ قَالَ أَخْبَرَنِي أَبِي أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَمْ تَرَوُا الإِنْسَانَ إِذَا مَاتَ شَخَصَ بَصَرُهُ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ فَذَلِكَ حِينَ يَتْبَعُ بَصَرُهُ نَفْسَهُ ‏"‏ ‏.‏\hadithno{2132}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Did you not see when the man died and his eyes were fixedly open? He (Abu Huraira) said: Yes. He (the Holy Prophet) said: It is due to the fact that when (the soul leaves the body) his eyesight follows the soul}}
\hadithdefcmd{muslim}{2133}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنِ الْعَلاَءِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{2133}\hadithtrans{This hadith is narrated on the authority of 'Ala' with the same chain of transmitters}}
\hadithdefcmd{muslim}{2134}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ كُلُّهُمْ عَنِ ابْنِ، عُيَيْنَةَ - قَالَ ابْنُ نُمَيْرٍ حَدَّثَنَا سُفْيَانُ، - عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ أَبِيهِ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، قَالَ قَالَتْ أُمُّ سَلَمَةَ لَمَّا مَاتَ أَبُو سَلَمَةَ قُلْتُ غَرِيبٌ وَفِي أَرْضِ غُرْبَةٍ لأَبْكِيَنَّهُ بُكَاءً يُتَحَدَّثُ عَنْهُ ‏.‏ فَكُنْتُ قَدْ تَهَيَّأْتُ لِلْبُكَاءِ عَلَيْهِ إِذْ أَقْبَلَتِ امْرَأَةٌ مِنَ الصَّعِيدِ تُرِيدُ أَنْ تُسْعِدَنِي فَاسْتَقْبَلَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏ "‏ أَتُرِيدِينَ أَنْ تُدْخِلِي الشَّيْطَانَ بَيْتًا أَخْرَجَهُ اللَّهُ مِنْهُ ‏"‏ ‏.‏ مَرَّتَيْنِ فَكَفَفْتُ عَنِ الْبُكَاءِ فَلَمْ أَبْكِ ‏.‏\hadithno{2134}\hadithtrans{Umm Salama reported:When Abu Salama died I said: I am a stranger in a strange land; I shall weep for him in a manner that would be talked of. I made preparation for weeping for him when a woman from the upper side of the city came there who intended to help me (in weeping). She happened to come across the Messenger of Allah (ﷺ) and he said: Do you intend to bring the devil into a house from which Allah has twice driven him out? I (Umm Salama), therefore, refrained from weeping and I did not weep}}
\hadithdefcmd{muslim}{2135}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأَرْسَلَتْ إِلَيْهِ إِحْدَى بَنَاتِهِ تَدْعُوهُ وَتُخْبِرُهُ أَنَّ صَبِيًّا لَهَا - أَوِ ابْنًا لَهَا - فِي الْمَوْتِ فَقَالَ لِلرَّسُولِ ‏"‏ ارْجِعْ إِلَيْهَا فَأَخْبِرْهَا إِنَّ لِلَّهِ مَا أَخَذَ وَلَهُ مَا أَعْطَى وَكُلُّ شَىْءٍ عِنْدَهُ بِأَجَلٍ مُسَمًّى فَمُرْهَا فَلْتَصْبِرْ وَلْتَحْتَسِبْ ‏"‏ فَعَادَ الرَّسُولُ فَقَالَ إِنَّهَا قَدْ أَقْسَمَتْ لَتَأْتِيَنَّهَا ‏.‏ قَالَ فَقَامَ النَّبِيُّ صلى الله عليه وسلم وَقَامَ مَعَهُ سَعْدُ بْنُ عُبَادَةَ وَمُعَاذُ بْنُ جَبَلٍ وَانْطَلَقْتُ مَعَهُمْ فَرُفِعَ إِلَيْهِ الصَّبِيُّ وَنَفْسُهُ تَقَعْقَعُ كَأَنَّهَا فِي شَنَّةٍ فَفَاضَتْ عَيْنَاهُ فَقَالَ لَهُ سَعْدٌ مَا هَذَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ هَذِهِ رَحْمَةٌ جَعَلَهَا اللَّهُ فِي قُلُوبِ عِبَادِهِ وَإِنَّمَا يَرْحَمُ اللَّهُ مِنْ عِبَادِهِ الرُّحَمَاءَ ‏"‏ ‏.‏\hadithno{2135}\hadithtrans{Usama b. Zaid reported:While we were with the Messenger of Allah (ﷺ), one of his daughters sent to him (the Messenger) to call him and inform him that her child or her son was dying. The Messenger of Allah (ﷺ) told the messenger to go back and tell her that what Allah had taken belonged to Him, and to him belonged what He granted; and He has an appointed time for everything. So you (the messenger) order her to show endurance and seek reward from Allah. The messenger came back and said: She adjures him to come to her. He got up to go accompanied by Sa'd b. 'Ubada, Mu'adh b. Jabal, and I also went along with them. The child was lifted to him and his soul was feeling as restless as if it was in an old (waterskin). His (Prophet's) eyes welled up with tears. Sa'd said: What is this, Messenger of Allah? He replied: This is compassion which Allah has placed in the hearts of His servants, and God shows compassion only to those of His servants who are compassionate}}
\hadithdefcmd{muslim}{2136}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا ابْنُ فُضَيْلٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي، شَيْبَةَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، جَمِيعًا عَنْ عَاصِمٍ الأَحْوَلِ، بِهَذَا الإِسْنَادِ ‏.‏ غَيْرَ أَنَّ حَدِيثَ حَمَّادٍ أَتَمُّ وَأَطْوَلُ ‏.‏\hadithno{2136}\hadithtrans{This hadith has been narrated by another chain of transmitters on the authority of 'Asim al-Ahwal}}
\hadithdefcmd{muslim}{2137}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى الصَّدَفِيُّ، وَعَمْرُو بْنُ سَوَّادٍ الْعَامِرِيُّ، قَالاَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ سَعِيدِ بْنِ الْحَارِثِ الأَنْصَارِيِّ، عَنْ عَبْدِ، اللَّهِ بْنِ عُمَرَ قَالَ اشْتَكَى سَعْدُ بْنُ عُبَادَةَ شَكْوَى لَهُ فَأَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُهُ مَعَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَسَعْدِ بْنِ أَبِي وَقَّاصٍ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ فَلَمَّا دَخَلَ عَلَيْهِ وَجَدَهُ فِي غَشِيَّةٍ فَقَالَ ‏"‏ أَقَدْ قَضَى ‏"‏ ‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ ‏.‏ فَبَكَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَأَى الْقَوْمُ بُكَاءَ رَسُولِ اللَّهِ صلى الله عليه وسلم بَكَوْا فَقَالَ ‏"‏ أَلاَ تَسْمَعُونَ إِنَّ اللَّهَ لاَ يُعَذِّبُ بِدَمْعِ الْعَيْنِ وَلاَ بِحُزْنِ الْقَلْبِ وَلَكِنْ يُعَذِّبُ بِهَذَا - وَأَشَارَ إِلَى لِسَانِهِ - أَوْ يَرْحَمُ ‏"‏ ‏.‏\hadithno{2137}\hadithtrans{Abdullah b. 'Umar said that Sa'd b. Ubada complained of illness. The Messenger of Allah (ﷺ) came to visit him accompanied by 'Abd al-Rahman b. 'Auf, Sa'd b. Abi Waqqas and 'Abdullah b. Mas'ud. As he entered (his room) he found him in a swoon. Upon this he said:Has he died? They said: Messenger of Allah, it is not so. The Messenger of Allah (ﷺ) wept. When the people saw Allah's Messenger (ﷺ) weeping, they also began to weep. He said. Listen, Allah does not punish for the tears that the eye sheds or the grief the heart feels, but He punishes for this (pointing to his tongue), or He may show mercy}}
\hadithdefcmd{muslim}{2138}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ جَهْضَمٍ، حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ عُمَارَةَ، - يَعْنِي ابْنَ غَزِيَّةَ - عَنْ سَعِيدِ بْنِ الْحَارِثِ بْنِ الْمُعَلَّى، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ كُنَّا جُلُوسًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ جَاءَهُ رَجُلٌ مِنَ الأَنْصَارِ فَسَلَّمَ عَلَيْهِ ثُمَّ أَدْبَرَ الأَنْصَارِيُّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَخَا الأَنْصَارِ كَيْفَ أَخِي سَعْدُ بْنُ عُبَادَةَ ‏"‏ ‏.‏ فَقَالَ صَالِحٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ يَعُودُهُ مِنْكُمْ ‏"‏ ‏.‏ فَقَامَ وَقُمْنَا مَعَهُ وَنَحْنُ بِضْعَةَ عَشَرَ مَا عَلَيْنَا نِعَالٌ وَلاَ خِفَافٌ وَلاَ قَلاَنِسُ وَلاَ قُمُصٌ نَمْشِي فِي تِلْكَ السِّبَاخِ حَتَّى جِئْنَاهُ فَاسْتَأْخَرَ قَوْمُهُ مِنْ حَوْلِهِ حَتَّى دَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ الَّذِينَ مَعَهُ ‏.‏\hadithno{2138}\hadithtrans{Abdullah b. 'Umar reported:While we were sitting with the Messenger of Allah (ﷺ), a person, one of the Ansar, came to him and greeted him. The Ansari then turned back. Upon this the Messenger of Allah (ﷺ) said: o brother of Ansar, how is my brother Sa'd be 'Ubada? He said: He is better. The Messenger of Allah (ﷺ) said: Who amongst you would visit him? He (the Holy Prophet) stood up and we also got up along with him, and we were more than ten persons. We had neither shoes with us, nor socks, nor caps, nor shirts. We walked on the barren land till we came to him. The people around him kept away till the Messenger of Allah (ﷺ) and his Companions with him came near him (Sa'd b. 'Ubada)}}
\hadithdefcmd{muslim}{2139}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ الْعَبْدِيُّ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، عَنْ ثَابِتٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الصَّبْرُ عِنْدَ الصَّدْمَةِ الأُولَى ‏"‏ ‏.‏\hadithno{2139}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as saying:Endurance is to be shown at the first blow}}
\hadithdefcmd{muslim}{2140}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا شُعْبَةُ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى عَلَى امْرَأَةٍ تَبْكِي عَلَى صَبِيٍّ لَهَا فَقَالَ لَهَا ‏"‏ اتَّقِي اللَّهَ وَاصْبِرِي ‏"‏ ‏.‏ فَقَالَتْ وَمَا تُبَالِي بِمُصِيبَتِي ‏.‏ فَلَمَّا ذَهَبَ قِيلَ لَهَا إِنَّهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَخَذَهَا مِثْلُ الْمَوْتِ فَأَتَتْ بَابَهُ فَلَمْ تَجِدْ عَلَى بَابِهِ بَوَّابِينَ فَقَالَتْ يَا رَسُولَ اللَّهِ لَمْ أَعْرِفْكَ ‏.‏ فَقَالَ ‏"‏ إِنَّمَا الصَّبْرُ عِنْدَ أَوَّلِ صَدْمَةٍ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ عِنْدَ أَوَّلِ الصَّدْمَةِ ‏"‏ ‏.‏\hadithno{2140}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) came to a woman who had been weeping for her (dead) child, and said to her:Fear Allah and show endurance. She (not recognising him) said: You have not been afflicted as I have been. When he (the Holy Prophet) had departed, it was said to her that he was the Messenger of Allah (ﷺ), she was mortally shocked. She came to his door and she did not find doorkeepers at his door. She said: Messenger of Allah. I did not recognise you. He said: Endurance is to be shown at first blow, or at the first blow}}
\hadithdefcmd{muslim}{2141}{وَحَدَّثَنَاهُ يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ يَعْنِي ابْنَ الْحَارِثِ، ح وَحَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، ح وَحَدَّثَنِي أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالُوا جَمِيعًا حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ عُثْمَانَ بْنِ عُمَرَ بِقِصَّتِهِ ‏.‏ وَفِي حَدِيثِ عَبْدِ الصَّمَدِ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِامْرَأَةٍ عِنْدَ قَبْرٍ ‏.‏\hadithno{2141}\hadithtrans{A hadith like this is narrated with the same chain of transmitters but with the addition of these words:" The Apostle of Allah (ﷺ) happened to pass by a woman (who was sitting) by the side of a grave}}
\hadithdefcmd{muslim}{2142}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، جَمِيعًا عَنِ ابْنِ بِشْرٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، - عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، قَالَ حَدَّثَنَا نَافِعٌ، عَنْ عَبْدِ اللَّهِ، أَنَّ حَفْصَةَ، بَكَتْ عَلَى عُمَرَ فَقَالَ مَهْلاً يَا بُنَيَّةُ أَلَمْ تَعْلَمِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمَيِّتَ يُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏\hadithno{2142}\hadithtrans{Abdullah b. 'Umar reported that Hafsa wept for 'Umar (when he was about to die). He ('Umar) said:Be quiet, my daughter. Don't you know that the Messenger of Allah (ﷺ) had said:" The deceased is punished because of his family's weeping over the death"?}}
\hadithdefcmd{muslim}{2143}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَيِّتُ يُعَذَّبُ فِي قَبْرِهِ بِمَا نِيحَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{2143}\hadithtrans{Umar reported Allah's Apostle (ﷺ) as saying:The dead is punished in the grave because of wailing on it}}
\hadithdefcmd{muslim}{2144}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ، بْنِ الْمُسَيَّبِ عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَيِّتُ يُعَذَّبُ فِي قَبْرِهِ بِمَا نِيحَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{2144}\hadithtrans{The same hadith is narrated on the authority of 'Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{2145}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي، صَالِحٍ عَنِ ابْنِ عُمَرَ، قَالَ لَمَّا طُعِنَ عُمَرُ أُغْمِيَ عَلَيْهِ فَصِيحَ عَلَيْهِ فَلَمَّا أَفَاقَ قَالَ أَمَا عَلِمْتُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ الْحَىِّ ‏"‏ ‏.‏\hadithno{2145}\hadithtrans{Ibn 'Umar reported:When 'Umar was wounded he fainted, and there was a loud lamentation over him. When he regained consciousness he said: Didn't you know that the Messenger of Allah (ﷺ) said:" The dead is punished because of the weeping of the living"?}}
\hadithdefcmd{muslim}{2146}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ لَمَّا أُصِيبَ عُمَرُ جَعَلَ صُهَيْبٌ يَقُولُ وَاأَخَاهْ ‏.‏ فَقَالَ لَهُ عُمَرُ يَا صُهَيْبُ أَمَا عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ الْحَىِّ ‏"‏ ‏.‏\hadithno{2146}\hadithtrans{Abu Burda narrated on the authority of his father that when 'Umar was wounded Suhaib uttered (loudly in lamentation):O brother! Upon this 'Umar said: Suhaib, did you not know that the Messenger of Allah (ﷺ) said:" The dead is punished because of the lamentation of the living"?}}
\hadithdefcmd{muslim}{2147}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شُعَيْبُ بْنُ صَفْوَانَ أَبُو يَحْيَى، عَنْ عَبْدِ الْمَلِكِ بْنِ، عُمَيْرٍ عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى، عَنْ أَبِي مُوسَى، قَالَ لَمَّا أُصِيبَ عُمَرُ أَقْبَلَ صُهَيْبٌ مِنْ مَنْزِلِهِ حَتَّى دَخَلَ عَلَى عُمَرَ فَقَامَ بِحِيَالِهِ يَبْكِي فَقَالَ عُمَرُ عَلاَمَ تَبْكِي أَعَلَىَّ تَبْكِي قَالَ إِي وَاللَّهِ لَعَلَيْكَ أَبْكِي يَا أَمِيرَ الْمُؤْمِنِينَ ‏.‏ قَالَ وَاللَّهِ لَقَدْ عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ يُبْكَى عَلَيْهِ يُعَذَّبُ ‏"‏ ‏.‏ قَالَ فَذَكَرْتُ ذَلِكَ لِمُوسَى بْنِ طَلْحَةَ فَقَالَ كَانَتْ عَائِشَةُ تَقُولُ إِنَّمَا كَانَ أُولَئِكَ الْيَهُودَ ‏.‏\hadithno{2147}\hadithtrans{Abu Musa reported that when 'Umar was wounded, there came Suhaib from his house and went to 'Umar and stood by his side, and began to wail. Upon this 'Umar said:What are you weeping for? Are you weeping for me? He said: By Allah, it is for you that I weep, O Commander of the believers. He said: By Allah, you already know that the Messenger of Allah (ﷺ) had said: He who is lamented upon is punished. I made a mention of it to Musa b. Talha, and he said that 'A'isha told that it concerned the Jews (only)}}
\hadithdefcmd{muslim}{2148}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، لَمَّا طُعِنَ عَوَّلَتْ عَلَيْهِ حَفْصَةُ فَقَالَ يَا حَفْصَةُ أَمَا سَمِعْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الْمُعَوَّلُ عَلَيْهِ يُعَذَّبُ ‏"‏ ‏.‏ وَعَوَّلَ عَلَيْهِ صُهَيْبٌ فَقَالَ عُمَرُ يَا صُهَيْبُ أَمَا عَلِمْتَ ‏"‏ أَنَّ الْمُعَوَّلَ عَلَيْهِ يُعَذَّبُ ‏"‏ ‏.‏\hadithno{2148}\hadithtrans{Anas reported that when 'Umar b. Khattab was wounded Hafsa lamented for him. Upon this he said:O Hafsa, did you not hear the Messenger of Allah (ﷺ) saying:" One who is lamented would be punished"? Suhaib also lamented over him. 'Umar told him also: O Suhaib, didn't you know that one who is lamented is punished?}}
\hadithdefcmd{muslim}{2151}{وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو عَنِ ابْنِ أَبِي مُلَيْكَةَ، كُنَّا فِي جَنَازَةِ أُمِّ أَبَانٍ بِنْتِ عُثْمَانَ وَسَاقَ الْحَدِيثَ وَلَمْ يَنُصَّ رَفْعَ الْحَدِيثِ عَنْ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم كَمَا نَصَّهُ أَيُّوبُ وَابْنُ جُرَيْجٍ وَحَدِيثُهُمَا أَتَمُّ مِنْ حَدِيثِ عَمْرٍو ‏.‏\hadithno{2151}\hadithtrans{Amr reported on the authority of Ibn Abu Mulaika:We were with the bier of Umm Aban, daughter of 'Uthman, and the rest of the hadith is the same, but he did not narrate it as a marfu' hadith on the authority of 'Umar from the Messenger of Allah (ﷺ) as it was narrated by Ayyub and Ibn Juraij, and the hadith narrated by them (Ayyub and Ibn Juraij) is more complete than that of 'Amr}}
\hadithdefcmd{muslim}{2152}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي عُمَرُ بْنُ مُحَمَّدٍ، أَنَّحَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمَيِّتَ يُعَذَّبُ بِبُكَاءِ الْحَىِّ ‏"‏ ‏.‏\hadithno{2152}\hadithtrans{Abdullah b. 'Umar reported that the Messenger of Allah (ﷺ) said:The dead is punished because of the lamentation of the living}}
\hadithdefcmd{muslim}{2153}{وَحَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، وَأَبُو الرَّبِيعِ الزَّهْرَانِيُّ، جَمِيعًا عَنْ حَمَّادٍ، - قَالَ خَلَفٌ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، قَالَ ذُكِرَ عِنْدَ عَائِشَةَ قَوْلُ ابْنِ عُمَرَ الْمَيِّتُ يُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏.‏ فَقَالَتْ رَحِمَ اللَّهُ أَبَا عَبْدِ الرَّحْمَنِ سَمِعَ شَيْئًا فَلَمْ يَحْفَظْهُ إِنَّمَا مَرَّتْ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم جَنَازَةُ يَهُودِيٍّ وَهُمْ يَبْكُونَ عَلَيْهِ فَقَالَ ‏ "‏ أَنْتُمْ تَبْكُونَ وَإِنَّهُ لَيُعَذَّبُ ‏"‏ ‏.‏\hadithno{2153}\hadithtrans{Hisham b. 'Urwa narrated on the authority of his father that the saying of Ibn 'Umar, viz." The dead would be punished because of the lamentation of his family over him" was mentioned to 'A'isha. Upon this she said:May Allah have mercy upon Abu 'Abd al-Rahman (the kunya of Ibn 'Umar) that he heard something but could not retain it (well). (The fact is) that the bier of a Jew passed before the Messenger of Allah (ﷺ) and (the members of his family) were waiting over him. Upon this he said: You are wailing and he is being punished}}
\hadithdefcmd{muslim}{2154}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، قَالَ ذُكِرَ عِنْدَ عَائِشَةَ أَنَّ ابْنَ عُمَرَ، يَرْفَعُ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏"‏ إِنَّ الْمَيِّتَ يُعَذَّبُ فِي قَبْرِهِ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏ فَقَالَتْ وَهَلَ إِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ لَيُعَذَّبُ بِخَطِيئَتِهِ أَوْ بِذَنْبِهِ وَإِنَّ أَهْلَهُ لَيَبْكُونَ عَلَيْهِ الآنَ ‏"‏ ‏.‏ وَذَاكَ مِثْلُ قَوْلِهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ عَلَى الْقَلِيبِ يَوْمَ بَدْرٍ وَفِيهِ قَتْلَى بَدْرٍ مِنَ الْمُشْرِكِينَ فَقَالَ لَهُمْ مَا قَالَ ‏"‏ إِنَّهُمْ لَيَسْمَعُونَ مَا أَقُولُ ‏"‏ ‏.‏ وَقَدْ وَهَلَ إِنَّمَا قَالَ ‏"‏ إِنَّهُمْ لَيَعْلَمُونَ أَنَّ مَا كُنْتُ أَقُولُ لَهُمْ حَقٌّ ‏"‏ ‏.‏ ثُمَّ قَرَأَتْ ‏\{‏ إِنَّكَ لاَ تُسْمِعُ الْمَوْتَى‏\}‏ ‏\{‏ وَمَا أَنْتَ بِمُسْمِعٍ مَنْ فِي الْقُبُورِ‏\}‏ يَقُولُ حِينَ تَبَوَّءُوا مَقَاعِدَهُمْ مِنَ النَّارِ ‏.‏\hadithno{2154}\hadithtrans{Hisham narrated on the authority of his father that it was mentioned to 'A'isha that Ibn 'Umar had narrated as marfu' hadith from the Messenger of Allah (ﷺ) that the dead would be punished in the grave because of the lamentation of his family for him. Upon this she said:He (Ibn 'Umar) missed (the point). The Messenger of Allah (ﷺ) had (in fact) said: He (the dead) is punished for his faults or for his sins, and the members of his family are wailing for him now. (This misunderstanding of Ibn 'Umar is similar to his saying: ) The Messenger of Allah (ﷺ) stood by the well in which were lying the dead bodies of those polytheists who had been killed on the Day of Badr, and he said to them what he had to say, i. e.: They hear what I say. But he (Ibn 'Umar) misunderstood. The Prophet (ﷺ) had only said: They (the dead) understand that what I used to say to them was truth. She then recited:" Certainly, thou canst not make the dead hear the call" (xxvii. 80), nor can you make those hear who are in the graves, nor can you inform them when they have taken their seats in Hell}}
\hadithdefcmd{muslim}{2155}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، بِهَذَا الإِسْنَادِ بِمَعْنَى حَدِيثِ أَبِي أُسَامَةَ وَحَدِيثُ أَبِي أُسَامَةَ أَتَمُّ ‏.‏\hadithno{2155}\hadithtrans{This hadith has been narrated by Ibn 'Urwa with the same chain of transmitters. The hadith narrated by Abu Usama is more complete}}
\hadithdefcmd{muslim}{2156}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ عَبْدِ اللَّهِ بْنِ، أَبِي بَكْرٍ عَنْ أَبِيهِ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّهَا أَخْبَرَتْهُ أَنَّهَا، سَمِعَتْ عَائِشَةَ، وَذُكِرَ، لَهَا أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ الْحَىِّ ‏.‏ فَقَالَتْ عَائِشَةُ يَغْفِرُ اللَّهُ لأَبِي عَبْدِ الرَّحْمَنِ أَمَا إِنَّهُ لَمْ يَكْذِبْ وَلَكِنَّهُ نَسِيَ أَوْ أَخْطَأَ إِنَّمَا مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى يَهُودِيَّةٍ يُبْكَى عَلَيْهَا فَقَالَ ‏ "‏ إِنَّهُمْ لَيَبْكُونَ عَلَيْهَا وَإِنَّهَا لَتُعَذَّبُ فِي قَبْرِهَا ‏"‏ ‏.‏\hadithno{2156}\hadithtrans{Amra daughter of 'Abd al Rahman narrated that she heard (from) 'A'isha and made a mention to her about 'Abdullah b. 'Umar as saying:The dead is punished because of the lamentation of the living. Upon this 'A'isha said: May Allah have mercy upon the father of 'Abd al-Rahman (Ibn 'Umar). He did not tell a lie, but he forgot or made a mistake. The Messenger of Allah (ﷺ) happened to pass by a (dead) Jewess who was being lamented. Upon this he said: They weep over her and she is being punished in the grave}}
\hadithdefcmd{muslim}{2157}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سَعِيدِ بْنِ عُبَيْدٍ الطَّائِيِّ، وَمُحَمَّدِ، بْنِ قَيْسٍ عَنْ عَلِيِّ بْنِ رَبِيعَةَ، قَالَ أَوَّلُ مَنْ نِيحَ عَلَيْهِ بِالْكُوفَةِ قَرَظَةُ بْنُ كَعْبٍ فَقَالَ الْمُغِيرَةُ بْنُ شُعْبَةَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ نِيحَ عَلَيْهِ فَإِنَّهُ يُعَذَّبُ بِمَا نِيحَ عَلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2157}\hadithtrans{Ali b. Rabi'a reported that the first one who was lamented upon in Kufa was Qaraza b. Ka'b. Mughira b. Shu'ba said:I heard the Messenger of Allah (ﷺ) saying: He who is lamented upon would be punished because of the lamentation for him on the Day of judgment}}
\hadithdefcmd{muslim}{2158}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ قَيْسٍ، الأَسْدِيُّ عَنْ عَلِيِّ بْنِ رَبِيعَةَ الأَسْدِيِّ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{2158}\hadithtrans{A hadith like this has been narrated by Mughira b. Shu'ba from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2159}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَرْوَانُ، - يَعْنِي الْفَزَارِيَّ - حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدٍ، الطَّائِيُّ عَنْ عَلِيِّ بْنِ رَبِيعَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{2159}\hadithtrans{This hadith has been narrated from the Messenger of Allah (ﷺ) through another chain of transmitters}}
\hadithdefcmd{muslim}{2160}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ، ح وَحَدَّثَنِي إِسْحَاقُ، بْنُ مَنْصُورٍ - وَاللَّفْظُ لَهُ - أَخْبَرَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا أَبَانٌ، حَدَّثَنَا يَحْيَى، أَنَّ زَيْدًا، حَدَّثَهُ أَنَّ أَبَا سَلاَّمٍ حَدَّثَهُ أَنَّ أَبَا مَالِكٍ الأَشْعَرِيَّ حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ أَرْبَعٌ فِي أُمَّتِي مِنْ أَمْرِ الْجَاهِلِيَّةِ لاَ يَتْرُكُونَهُنَّ الْفَخْرُ فِي الأَحْسَابِ وَالطَّعْنُ فِي الأَنْسَابِ وَالاِسْتِسْقَاءُ بِالنُّجُومِ وَالنِّيَاحَةُ ‏"‏ ‏.‏ وَقَالَ ‏"‏ النَّائِحَةُ إِذَا لَمْ تَتُبْ قَبْلَ مَوْتِهَا تُقَامُ يَوْمَ الْقِيَامَةِ وَعَلَيْهَا سِرْبَالٌ مِنْ قَطِرَانٍ وَدِرْعٌ مِنْ جَرَبٍ ‏"‏ ‏.‏\hadithno{2160}\hadithtrans{Abu Malik al-Ash'ari reported Allah's Messenger (ﷺ) as saying:Among my people there are four characteristics belonging to pre-Islamic period which they do not abandon: boasting of high rank, reviling other peoples' genealogies, seeking rain by stars, and walling. And he (further) said: If the wailing woman does not repent before she dies, she will be made to stand on the Day of Resurrection wearing a garment of pitch and a chemise of mange}}
\hadithdefcmd{muslim}{2161}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ أَبِي عُمَرَ، قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ أَخْبَرَتْنِي عَمْرَةُ، أَنَّهَا سَمِعَتْ عَائِشَةَ، تَقُولُ لَمَّا جَاءَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَتْلُ ابْنِ حَارِثَةَ وَجَعْفَرِ بْنِ أَبِي طَالِبٍ وَعَبْدِ اللَّهِ بْنِ رَوَاحَةَ جَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعْرَفُ فِيهِ الْحُزْنُ قَالَتْ وَأَنَا أَنْظُرُ مِنْ صَائِرِ الْبَابِ - شَقِّ الْبَابِ - فَأَتَاهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ نِسَاءَ جَعْفَرٍ وَذَكَرَ بُكَاءَهُنَّ فَأَمَرَهُ أَنْ يَذْهَبَ فَيَنْهَاهُنَّ فَذَهَبَ فَأَتَاهُ فَذَكَرَ أَنَّهُنَّ لَمْ يُطِعْنَهُ فَأَمَرَهُ الثَّانِيَةَ أَنْ يَذْهَبَ فَيَنْهَاهُنَّ فَذَهَبَ ثُمَّ أَتَاهُ فَقَالَ وَاللَّهِ لَقَدْ غَلَبْنَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَتْ فَزَعَمَتْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اذْهَبْ فَاحْثُ فِي أَفْوَاهِهِنَّ مِنَ التُّرَابِ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَقُلْتُ أَرْغَمَ اللَّهُ أَنْفَكَ وَاللَّهِ مَا تَفْعَلُ مَا أَمَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَا تَرَكْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنَ الْعَنَاءِ ‏.‏\hadithno{2161}\hadithtrans{A'isha reported that when the Messenger of Allah (ﷺ) was told that Ibn Haritha, Ja'far b. Abu Talib and Abdullah b. Rawaha were killed, he sat down, showing signs of grief. She (further) said:I was looking (at him) through the crevice of the door. A man came to him and mentioned that Ja'far's women were lamenting. He (the Holy Prophet) commanded him to go and forbid them (to do so). So he went away but came back and told (him) that they did not obey (him). He commanded him a second time to go and forbid them (to do so). He again went but came back to him and said: I swear by God, Messenger of Allah, that they have overpowered us. She ('A'isha) said that she thought the Messenger of Allah (ﷺ) had told (her) to throw dust in their mouths. Thereupon 'A'isha said: May Allah humble you! You did not do what Allah's Messenger (ﷺ) ordered you, nor did you stop annoying Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{2162}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، ح وَحَدَّثَنِي أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُسْلِمٍ - كُلُّهُمْ عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ ‏.‏ وَفِي حَدِيثِ عَبْدِ الْعَزِيزِ وَمَا تَرَكْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنَ الْعِيِّ ‏.‏\hadithno{2162}\hadithtrans{This hadith has been narrated by Yahya b. Sa'id with the same chain of transmitters like one narrated by 'Abd al-'Aziz (with the change of these words):" You did not spare the Messenger of Allah (ﷺ) the botheration}}
\hadithdefcmd{muslim}{2163}{حَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ أَخَذَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ الْبَيْعَةِ أَلاَّ نَنُوحَ فَمَا وَفَتْ مِنَّا امْرَأَةٌ إِلاَّ خَمْسٌ أُمُّ سُلَيْمٍ وَأُمُّ الْعَلاَءِ وَابْنَةُ أَبِي سَبْرَةَ امْرَأَةُ مُعَاذٍ أَوِ ابْنَةُ أَبِي سَبْرَةَ وَامْرَأَةُ مُعَاذٍ .‏\hadithno{2163}\hadithtrans{Umm 'Atiyya reported:The Messenger of Allah (ﷺ) took a promise from us along with the oath of Allegiance that we would not lament. But only five among us fulfilled the promise (and they are) Umm Sulaim, and Umm al-'Ala', and the daughter of Abu Sabra the wife of Mu'adh, or daughter of Abu Sabra and wife of Mu'adh}}
\hadithdefcmd{muslim}{2164}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَسْبَاطٌ، حَدَّثَنَا هِشَامٌ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ أَخَذَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْبَيْعَةِ أَلاَّ تَنُحْنَ فَمَا وَفَتْ مِنَّا غَيْرُ خَمْسٍ مِنْهُنَّ أُمُّ سُلَيْمٍ ‏.‏\hadithno{2164}\hadithtrans{Umm 'Atiyya reported that the Messenger of Allah (ﷺ) took pledge from us (including this promise) that we would not lament. Only five amongst us fulfilled the promise, and one of them (who fulfilled the promise) was Umm Sulaim}}
\hadithdefcmd{muslim}{2165}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، - قَالَ زُهَيْرٌ حَدَّثَنَا مُحَمَّدُ بْنُ خَازِمٍ، - حَدَّثَنَا عَاصِمٌ، عَنْ حَفْصَةَ، عَنْ أُمِّ، عَطِيَّةَ قَالَتْ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ يُبَايِعْنَكَ عَلَى أَنْ لاَ يُشْرِكْنَ بِاللَّهِ شَيْئًا‏\}‏ ‏\{‏ وَلاَ يَعْصِينَكَ فِي مَعْرُوفٍ‏\}‏ قَالَتْ كَانَ مِنْهُ النِّيَاحَةُ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ إِلاَّ آلَ فُلاَنٍ فَإِنَّهُمْ كَانُوا أَسْعَدُونِي فِي الْجَاهِلِيَّةِ فَلاَ بُدَّ لِي مِنْ أَنْ أُسْعِدَهُمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِلاَّ آلَ فُلاَنٍ ‏"‏ ‏.‏\hadithno{2165}\hadithtrans{Hafsa narrated on the authority of Umm 'Atiyya that she said:When this verse was revealed:" When believing women came to thee giving thee a pledge that they will not associate aught with Allah, and will not disobey thee in good" (lx. 12), she (Umm Atiyya) said: In (this pledge) was also included wailing. I said: Messenger of Allah, except members of such a tribe who helped me (in lamentation) during pre-Islamic days, there is left no alternative for me, but that I should also help them. Upon this the Messenger of Allah (ﷺ) said: (Yes) but only in case of the members of such a tribe}}
\hadithdefcmd{muslim}{2166}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، أَخْبَرَنَا أَيُّوبُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ قَالَتْ أُمُّ عَطِيَّةَ كُنَّا نُنْهَى عَنِ اتِّبَاعِ الْجَنَائِزِ وَلَمْ يُعْزَمْ عَلَيْنَا ‏.‏\hadithno{2166}\hadithtrans{Umm 'Atiyya reported:We were forbidden to follow the bier, but it was not made absolute on us}}
\hadithdefcmd{muslim}{2167}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كِلاَهُمَا عَنْ هِشَامٍ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ نُهِينَا عَنِ اتِّبَاعِ الْجَنَائِزِ، وَلَمْ يُعْزَمْ عَلَيْنَا ‏.‏\hadithno{2167}\hadithtrans{Umm 'Atiyya reported:We were refrained from following the bier, but it was not made absolute on us}}
\hadithdefcmd{muslim}{2168}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ دَخَلَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم وَنَحْنُ نَغْسِلُ ابْنَتَهُ فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّ ذَلِكَ بِمَاءٍ وَسِدْرٍ وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَلْقَى إِلَيْنَا حِقْوَهُ فَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{2168}\hadithtrans{Umm 'Atiyya reported:The Apostle of Allah (ﷺ) came to us when we were bathing his daughter, and he told us: Wash her with water and (with the leaves of) the lote tree, three or five times, or more than that if you think fit, and put camphor or something like camphor in the last washing; then inform me when you have finished. So when we had finished, we informed him, and he gave to us his (own) under-garment saying:" Put it next her body}}
\hadithdefcmd{muslim}{2169}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ مَشَطْنَاهَا ثَلاَثَةَ قُرُونٍ ‏.‏\hadithno{2169}\hadithtrans{Umm 'Atiyya reported:We braided her hair in three plaits}}
\hadithdefcmd{muslim}{2170}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، ح وَحَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَقُتَيْبَةُ، بْنُ سَعِيدٍ قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، كُلُّهُمْ عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ تُوُفِّيَتْ إِحْدَى بَنَاتِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَفِي حَدِيثِ ابْنِ عُلَيَّةَ قَالَتْ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَغْسِلُ ابْنَتَهُ ‏.‏ وَفِي حَدِيثِ مَالِكٍ قَالَتْ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ تُوُفِّيَتِ ابْنَتُهُ ‏.‏ بِمِثْلِ حَدِيثِ يَزِيدَ بْنِ زُرَيْعٍ عَنْ أَيُّوبَ عَنْ مُحَمَّدٍ عَنْ أُمِّ عَطِيَّةَ ‏.‏\hadithno{2170}\hadithtrans{Umm 'Atiyya reported:One of the daughters of the Messenger of Allah (ﷺ) died. And in the hadith transmitted by Ibn 'Ulayya (the words are): The Messenger of Allah (ﷺ) came to us and we were washing his daughter. And in the hadith transmitted by Malik (the words are): There came in (our apartment) the Messenger of Allah (way peace be upon him) when his daughter died. The rest of the hadith is the same as narrated by Yazid b. Zurai' from Ayyub from Muhammad from Umm 'Atiyya}}
\hadithdefcmd{muslim}{2171}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، ‏.‏ بِنَحْوِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ ثَلاَثًا أَوْ خَمْسًا أَوْ سَبْعًا أَوْ أَكْثَرَ مِنْ ذَلِكِ إِنْ رَأَيْتُنَّ ذَلِكِ ‏"‏ ‏.‏ فَقَالَتْ حَفْصَةُ عَنْ أُمِّ عَطِيَّةَ وَجَعَلْنَا رَأْسَهَا ثَلاَثَةَ قُرُونٍ ‏.‏\hadithno{2171}\hadithtrans{A hadith like this has been transmitted by Hafsa on the authority of Umm 'Atiyya with the exception (of these words that the Prophet asked them to wash her dead body):" three times, five times, seven times, or more than that, if you deem fit:" Hafsa (further) said on the authority of Umm 'Atiyya: We braided (the hair) of her head in three plaits}}
\hadithdefcmd{muslim}{2172}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، وَأَخْبَرَنَا أَيُّوبُ، قَالَ وَقَالَتْ حَفْصَةُ عَنْ أُمِّ عَطِيَّةَ، قَالَتِ اغْسِلْنَهَا وِتْرًا ثَلاَثًا أَوْ خَمْسًا أَوْ سَبْعًا قَالَ وَقَالَتْ أُمُّ عَطِيَّةَ مَشَطْنَاهَا ثَلاَثَةَ قُرُونٍ ‏.‏\hadithno{2172}\hadithtrans{Umm 'Atiyya reported:We washed her an odd number of times, i. e. three, five or seven times; and Umm 'Atiyya (further) said: We braided her hair in three plaits}}
\hadithdefcmd{muslim}{2173}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، - قَالَ عَمْرٌو حَدَّثَنَا مُحَمَّدُ بْنُ خَازِمٍ أَبُو مُعَاوِيَةَ، - حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ لَمَّا مَاتَتْ زَيْنَبُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اغْسِلْنَهَا وِتْرًا ثَلاَثًا أَوْ خَمْسًا وَاجْعَلْنَ فِي الْخَامِسَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا غَسَلْتُنَّهَا فَأَعْلِمْنَنِي ‏"‏ ‏.‏ قَالَتْ فَأَعْلَمْنَاهُ ‏.‏ فَأَعْطَانَا حِقْوَهُ وَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{2173}\hadithtrans{Umm 'Atiyya reported:When Zainab the daughter of the Messenger of Allah (ﷺ) died, he said to us: Wash her odd number of times, i. e. three or five times, and put camphor or something-like camphor at the fifth time, and after you have washed her inform me. So we informed him and he gave us his under-garment, saying:" Put it next her body}}
\hadithdefcmd{muslim}{2174}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ حَفْصَةَ، بِنْتِ سِيرِينَ عَنْ أُمِّ عَطِيَّةَ، قَالَتْ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَغْسِلُ إِحْدَى بَنَاتِهِ فَقَالَ ‏ "‏ اغْسِلْنَهَا وِتْرًا خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكِ ‏"‏ ‏.‏ بِنَحْوِ حَدِيثِ أَيُّوبَ وَعَاصِمٍ وَقَالَ فِي الْحَدِيثِ قَالَتْ فَضَفَرْنَا شَعْرَهَا ثَلاَثَةَ أَثْلاَثٍ قَرْنَيْهَا وَنَاصِيَتَهَا ‏.‏\hadithno{2174}\hadithtrans{Umm 'Atiyya reported:There came to us the Messenger of Allah (ﷺ) as we were washing one of his daughters. So he said: Wash her (dead body) an odd number of times, five times or more than that, the rest of the hadith is the same. She (further) said: We braided her hair in three plaits: (two) on the sides of her head and one on her forehead}}
\hadithdefcmd{muslim}{2175}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ خَالِدٍ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَيْثُ أَمَرَهَا أَنْ تَغْسِلَ ابْنَتَهُ قَالَ لَهَا ‏ "‏ ابْدَأْنَ بِمَيَامِنِهَا وَمَوَاضِعِ الْوُضُوءِ مِنْهَا ‏"‏ ‏.‏\hadithno{2175}\hadithtrans{Umm 'Atiyya reported that when the Messenger of Allah (ﷺ) asked her to wash his daughter, he told her to start from the right side, and with those parts of the body over which Wudu' is performed}}
\hadithdefcmd{muslim}{2176}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ كُلُّهُمْ عَنِ ابْنِ عُلَيَّةَ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، - عَنْ خَالِدٍ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُنَّ فِي غَسْلِ ابْنَتِهِ ‏ "‏ ابْدَأْنَ بِمَيَامِنِهَا وَمَوَاضِعِ الْوُضُوءِ مِنْهَا ‏"‏ ‏.‏\hadithno{2176}\hadithtrans{Umm 'Atiyya reported that the Messenger of Allah (ﷺ) said to them (the women) in regard to the washing of his daughter to start from the right side and with those parts of the body over which Wudu' is performed}}
\hadithdefcmd{muslim}{2177}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لِيَحْيَى قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، - عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ خَبَّابِ بْنِ الأَرَتِّ، قَالَ هَاجَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَبِيلِ اللَّهِ نَبْتَغِي وَجْهَ اللَّهِ فَوَجَبَ أَجْرُنَا عَلَى اللَّهِ فَمِنَّا مَنْ مَضَى لَمْ يَأْكُلْ مِنْ أَجْرِهِ شَيْئًا مِنْهُمْ مُصْعَبُ بْنُ عُمَيْرٍ ‏.‏ قُتِلَ يَوْمَ أُحُدٍ فَلَمْ يُوجَدْ لَهُ شَىْءٌ يُكَفَّنُ فِيهِ إِلاَّ نَمِرَةٌ فَكُنَّا إِذَا وَضَعْنَاهَا عَلَى رَأْسِهِ خَرَجَتْ رِجْلاَهُ وَإِذَا وَضَعْنَاهَا عَلَى رِجْلَيْهِ خَرَجَ رَأْسُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ضَعُوهَا مِمَّا يَلِي رَأْسَهُ وَاجْعَلُوا عَلَى رِجْلَيْهِ الإِذْخِرَ ‏"‏ ‏.‏ وَمِنَّا مَنْ أَيْنَعَتْ لَهُ ثَمَرَتُهُ فَهُوَ يَهْدِبُهَا ‏.‏\hadithno{2177}\hadithtrans{Khabbab al-Aratt reported:We migrated with the Messenger of Allah (ﷺ) in the path of Allah seeking Allah's pleasure alone. Thus our reward was assured with Allah. And amongst us were those who spent life (in such a state of piety and austerity) that nothing consumed their reward. Mus'ab b. 'Umair was one of them. He was killed on the Day of Uhud, and nothing but a woollen cloak was found to shroud him. When we covered his head with it, his feet became uncovered, and when we covered his feet, his head was uncovered. Upon this the Messenger of Allah (ﷺ) said: Place it (this cloak) on the side of his head and cover his feet with grass. And there is one amongst us for whom the fruit is ripened and he enjoys it}}
\hadithdefcmd{muslim}{2178}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا مِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ ‏.‏\hadithno{2178}\hadithtrans{A hadith like this has been narrated by 'Uyaina on the authority of A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{2179}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُفِّنَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ثَلاَثَةِ أَثْوَابٍ بِيضٍ سَحُولِيَّةٍ مِنْ كُرْسُفٍ لَيْسَ فِيهَا قَمِيصٌ وَلاَ عِمَامَةٌ أَمَّا الْحُلَّةُ فَإِنَّمَا شُبِّهَ عَلَى النَّاسِ فِيهَا أَنَّهَا اشْتُرِيَتْ لَهُ لِيُكَفَّنَ فِيهَا فَتُرِكَتِ الْحُلَّةُ وَكُفِّنَ فِي ثَلاَثَةِ أَثْوَابٍ بِيضٍ سَحُولِيَّةٍ فَأَخَذَهَا عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ فَقَالَ لأَحْبِسَنَّهَا حَتَّى أُكَفِّنَ فِيهَا نَفْسِي ثُمَّ قَالَ لَوْ رَضِيَهَا اللَّهُ عَزَّ وَجَلَّ لِنَبِيِّهِ لَكَفَّنَهُ فِيهَا ‏.‏ فَبَاعَهَا وَتَصَدَّقَ بِثَمَنِهَا ‏.‏\hadithno{2179}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) was shrouded in three cotton garments of white Yamani stuff from Sahul, among which was neither a shirt nor a turban; and so far as Hullah is concerned there was some doubt about it in the minds of people, that it was brought for him in order to shroud him with it, but it was abandoned, and he was shrouded in three cotton garments of white Yamani stuff from Sahul. Then 'Abdullah b. Abu Bakr got it and said:I would keep it in order to shroud myself in it. He then said: If Allah, the Exalted and Majestic, would have desired it for His Apostle, he would have been shrouded with it. So he sold it and gave its price in charity}}
\hadithdefcmd{muslim}{2180}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أُدْرِجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حُلَّةٍ يَمَنِيَّةٍ كَانَتْ لِعَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ ثُمَّ نُزِعَتْ عَنْهُ وَكُفِّنَ فِي ثَلاَثَةِ أَثْوَابٍ سُحُولٍ يَمَانِيَةٍ لَيْسَ فِيهَا عِمَامَةٌ وَلاَ قَمِيصٌ فَرَفَعَ عَبْدُ اللَّهِ الْحُلَّةَ فَقَالَ أُكَفَّنُ فِيهَا ‏.‏ ثُمَّ قَالَ لَمْ يُكَفَّنْ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأُكَفَّنُ فِيهَا ‏.‏ فَتَصَدَّقَ بِهَا ‏\hadithno{2180}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) was wrapped in a Yamani wrapper which belonged to 'Abdullah b Abu Bakr; then it was removed from him, and he was shrouded in three cotton sheets of white Yamani stuff from Sahul among which was neither a shirt nor a turban. 'Abdullah took up the Hullah and said:I would be shrouded in it, but then said: How is it that I should be shrouded in it in which the Messenger of Allah (ﷺ) was not shrouded! So he gave it in charity}}
\hadithdefcmd{muslim}{2181}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، وَابْنُ، عُيَيْنَةَ وَابْنُ إِدْرِيسَ وَعَبْدَةُ وَوَكِيعٌ ح وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ وَلَيْسَ فِي حَدِيثِهِمْ قِصَّةُ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ ‏.‏\hadithno{2181}\hadithtrans{This hadith is narrated on the authority of Hisham with the same chain of transmitters, but in the hadith narrated by him there is no mention of the story of 'Abdullah b. Abu Bakr}}
\hadithdefcmd{muslim}{2182}{وَحَدَّثَنِي ابْنُ أَبِي عُمَرَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ يَزِيدَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، أَنَّهُ قَالَ سَأَلْتُ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ لَهَا فِي كَمْ كُفِّنَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَتْ فِي ثَلاَثَةِ أَثْوَابٍ سَحُولِيَّةٍ ‏.‏\hadithno{2182}\hadithtrans{Abu Salama said:I asked 'A'isha with how many garments the Messenger of Allah (ﷺ) was shourded. She said: With three garments of Sahul}}
\hadithdefcmd{muslim}{2183}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَحَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنِي وَقَالَ، الآخَرَانِ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ، شِهَابٍ أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ قَالَتْ سُجِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ مَاتَ بِثَوْبِ حِبَرَةٍ ‏.‏\hadithno{2183}\hadithtrans{A'isha reported:When the Messenger of Allah (may peace be upom him) died, he was covered with a Yamani wrapper}}
\hadithdefcmd{muslim}{2184}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ سَوَاءً ‏.‏\hadithno{2184}\hadithtrans{This hadith has been narrated by Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{2185}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، وَحَجَّاجُ بْنُ الشَّاعِرِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يُحَدِّثُ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَ يَوْمًا فَذَكَرَ رَجُلاً مِنْ أَصْحَابِهِ قُبِضَ فَكُفِّنَ فِي كَفَنٍ غَيْرِ طَائِلٍ وَقُبِرَ لَيْلاً فَزَجَرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يُقْبَرَ الرَّجُلُ بِاللَّيْلِ حَتَّى يُصَلَّى عَلَيْهِ إِلاَّ أَنْ يُضْطَرَّ إِنْسَانٌ إِلَى ذَلِكَ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا كَفَّنَ أَحَدُكُمْ أَخَاهُ فَلْيُحَسِّنْ كَفَنَهُ ‏"‏ ‏.‏\hadithno{2185}\hadithtrans{Jabir b. 'Abdullah reported:Allah's Messenger (ﷺ) one day in the course of his sermon made mention of a person among his Companions who had died and had been wrapped in a shroud not long (enough to cover his whole body) and was buried during the night. The Apostle of Allah (ﷺ) reprimanded (the audience) that a person was buried during the night (in a state that) funeral prayer could not be offered (over him by the Messenger of Allah). (And this is permissible only) when it becomes a dire necessity for a man. The Apostle of Allah (ﷺ) also said: When any one of you shrouds his brother, he should shroud him well}}
\hadithdefcmd{muslim}{2186}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْرِعُوا بِالْجَنَازَةِ فَإِنْ تَكُ صَالِحَةً فَخَيْرٌ - لَعَلَّهُ قَالَ - تُقَدِّمُونَهَا عَلَيْهِ وَإِنْ تَكُنْ غَيْرَ ذَلِكَ فَشَرٌّ تَضَعُونَهُ عَنْ رِقَابِكُمْ ‏"‏ ‏.‏\hadithno{2186}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:Make haste at a funeral; if the dead person was good, it is a good state to which you are sending him on; but if he was otherwise it is an evil of which you are ridding yourselves}}
\hadithdefcmd{muslim}{2187}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي حَفْصَةَ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ أَنَّ فِي حَدِيثِ مَعْمَرٍ قَالَ لاَ أَعْلَمُهُ إِلاَّ رَفَعَ الْحَدِيثَ ‏.‏\hadithno{2187}\hadithtrans{This hadith has been narrated by another chain of transmitters except with this variation (of words) that in the hadith narrated by Ma'mar (the words are):" I do not know whether the hadith is marfu}}
\hadithdefcmd{muslim}{2188}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، قَالَ هَارُونُ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَبُو أُمَامَةَ بْنُ سَهْلِ بْنِ حُنَيْفٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَسْرِعُوا بِالْجَنَازَةِ فَإِنْ كَانَتْ صَالِحَةً قَرَّبْتُمُوهَا إِلَى الْخَيْرِ وَإِنْ كَانَتْ غَيْرَ ذَلِكَ كَانَ شَرًّا تَضَعُونَهُ عَنْ رِقَابِكُمْ ‏"‏ ‏.‏\hadithno{2188}\hadithtrans{Abu Huraira reported Allah's Messenger as saying:Hasten at a funeral, for if (the dead person) is good, you would (soon) bring him close to the good. And if it is otherwise, it is an evil of which you are ridding yourselves}}
\hadithdefcmd{muslim}{2189}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، - وَاللَّفْظُ لِهَارُونَ وَحَرْمَلَةَ - قَالَ هَارُونُ حَدَّثَنَا وَقَالَ الآخَرَانِ أَخْبَرَنَا ابْنُ وَهْبٍ أَخْبَرَنِي يُونُسُ عَنِ ابْنِ شِهَابٍ قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ هُرْمُزَ الأَعْرَجُ أَنَّ أَبَا هُرَيْرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ شَهِدَ الْجَنَازَةَ حَتَّى يُصَلَّى عَلَيْهَا فَلَهُ قِيرَاطٌ وَمَنْ شَهِدَهَا حَتَّى تُدْفَنَ فَلَهُ قِيرَاطَانِ ‏"‏ ‏.‏ قِيلَ وَمَا الْقِيرَاطَانِ قَالَ ‏"‏ مِثْلُ الْجَبَلَيْنِ الْعَظِيمَيْنِ ‏"‏ ‏.‏ انْتَهَى حَدِيثُ أَبِي الطَّاهِرِ وَزَادَ الآخَرَانِ قَالَ ابْنُ شِهَابٍ قَالَ سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ وَكَانَ ابْنُ عُمَرَ يُصَلِّي عَلَيْهَا ثُمَّ يَنْصَرِفُ فَلَمَّا بَلَغَهُ حَدِيثُ أَبِي هُرَيْرَةَ قَالَ لَقَدْ ضَيَّعْنَا قَرَارِيطَ كَثِيرَةً ‏.‏\hadithno{2189}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who attends the funeral till the prayer is offered for (the dead), for him is the reward of one qirat, and he who attends (and stays) till he is buried, for him is the reward of two qirats. It was said: What are the qirats? He said: They are equivalent to two huge mountains. Two other narrators added: Ibn 'Umar used to pray and then depart (without waiting for the burial of the dead). When the tradition of Abu Huraira reached him, he said:" We have lost many qirats}}
\hadithdefcmd{muslim}{2190}{حَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، ح وَحَدَّثَنَا ابْنُ رَافِعٍ، وَعَبْدُ، بْنُ حُمَيْدٍ عَنْ عَبْدِ الرَّزَّاقِ، كِلاَهُمَا عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي، هُرَيْرَةَ عَنِ النَّبِيَّ صلى الله عليه وسلم إِلَى قَوْلِهِ الْجَبَلَيْنِ الْعَظِيمَيْنِ ‏.‏ وَلَمْ يَذْكُرَا مَا بَعْدَهُ وَفِي حَدِيثِ عَبْدِ الأَعْلَى حَتَّى يُفْرَغَ مِنْهَا وَفِي حَدِيثِ عَبْدِ الرَّزَّاقِ حَتَّى تُوضَعَ فِي اللَّحْدِ\hadithno{2190}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of narrators up to these words:" two great mountains." No mention is made of what followed (these words) ; and in the hadith transmitted by 'Abd al- A'la (the words are):" till (the burial) is complete." In the hadith transmitted by 'Abd ar-Razzaq (the words are):" till he is placed in the grave}}
\hadithdefcmd{muslim}{2191}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ حَدَّثَنِي عُقَيْلُ، بْنُ خَالِدٍ عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ حَدَّثَنِي رِجَالٌ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ مَعْمَرٍ وَقَالَ ‏ "‏ وَمَنِ اتَّبَعَهَا حَتَّى تُدْفَنَ ‏"‏ ‏.‏\hadithno{2191}\hadithtrans{This hadith is narrated on thp authority of Abu Huraira through another chain of transmitters (with these words):" He who followed it (the bier) till he (the dead) is buried}}
\hadithdefcmd{muslim}{2192}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنِي سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ صَلَّى عَلَى جَنَازَةٍ وَلَمْ يَتْبَعْهَا فَلَهُ قِيرَاطٌ فَإِنْ تَبِعَهَا فَلَهُ قِيرَاطَانِ ‏"‏ ‏.‏ قِيلَ وَمَا الْقِيرَاطَانِ قَالَ ‏"‏ أَصْغَرُهُمَا مِثْلُ أُحُدٍ ‏"‏ .‏\hadithno{2192}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:He who offered prayer over the dead, but did not follow the bier, for him is the reward of one qirat, and he who followed it, for him is the reward of two qirats. It was asked what the qirats were. He said: The smaller amongst the two is equivalent to Uhud}}
\hadithdefcmd{muslim}{2193}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، حَدَّثَنِي أَبُو حَازِمٍ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ صَلَّى عَلَى جَنَازَةٍ فَلَهُ قِيرَاطٌ وَمَنِ اتَّبَعَهَا حَتَّى تُوضَعَ فِي الْقَبْرِ فَقِيرَاطَانِ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا أَبَا هُرَيْرَةَ وَمَا الْقِيرَاطُ قَالَ ‏"‏ مِثْلُ أُحُدٍ ‏"‏ ‏.‏\hadithno{2193}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who offers prayer for the dead, for him is (the reward of) one qirat; and he who follows the bier till it is placed in the grave, for him (is the reward of) two qirats. I (Abu Hazim, one of the narrators) said: Abu Huraira, what is a qirat? He said: It is like the hill of Uhud}}
\hadithdefcmd{muslim}{2194}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرٌ، - يَعْنِي ابْنَ حَازِمٍ - حَدَّثَنَا نَافِعٌ، قَالَ قِيلَ لاِبْنِ عُمَرَ إِنَّ أَبَا هُرَيْرَةَ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ تَبِعَ جَنَازَةً فَلَهُ قِيرَاطٌ مِنَ الأَجْرِ ‏"‏ ‏.‏ فَقَالَ ابْنُ عُمَرَ أَكْثَرَ عَلَيْنَا أَبُو هُرَيْرَةَ ‏.‏ فَبَعَثَ إِلَى عَائِشَةَ فَسَأَلَهَا فَصَدَّقَتْ أَبَا هُرَيْرَةَ فَقَالَ ابْنُ عُمَرَ لَقَدْ فَرَّطْنَا فِي قَرَارِيطَ كَثِيرَةٍ ‏.‏\hadithno{2194}\hadithtrans{Nafi' narrated that it was said to Ibn 'Umar that Abu Huraira reported to have heard Allah's Messenger (ﷺ) as saying:He who follows the bier, for him is the reward of one qirat. Ibn 'Umar said: Abu Huraira narrated it too often. So he sent (a messenger to) 'A'isha to ascertain (the fact). She ('A'isha) testified Abu Huraira. Ibn 'Umar said: We missed so many qirats}}
\hadithdefcmd{muslim}{2195}{وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنِي حَيْوَةُ، حَدَّثَنِي أَبُو صَخْرٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، أَنَّهُ حَدَّثَهُ أَنَّ دَاوُدَ بْنَ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ حَدَّثَهُ عَنْ أَبِيهِ، أَنَّهُ كَانَ قَاعِدًا عِنْدَ عَبْدِ اللَّهِ بْنِ عُمَرَ إِذْ طَلَعَ خَبَّابٌ صَاحِبُ الْمَقْصُورَةِ فَقَالَ يَا عَبْدَ اللَّهِ بْنَ عُمَرَ أَلاَ تَسْمَعُ مَا يَقُولُ أَبُو هُرَيْرَةَ إِنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ خَرَجَ مَعَ جَنَازَةٍ مِنْ بَيْتِهَا وَصَلَّى عَلَيْهَا ثُمَّ تَبِعَهَا حَتَّى تُدْفَنَ كَانَ لَهُ قِيرَاطَانِ مِنْ أَجْرٍ كُلُّ قِيرَاطٍ مِثْلُ أُحُدٍ وَمَنْ صَلَّى عَلَيْهَا ثُمَّ رَجَعَ كَانَ لَهُ مِنَ الأَجْرِ مِثْلُ أُحُدٍ ‏"‏ ‏.‏ فَأَرْسَلَ ابْنُ عُمَرَ خَبَّابًا إِلَى عَائِشَةَ يَسْأَلُهَا عَنْ قَوْلِ أَبِي هُرَيْرَةَ ثُمَّ يَرْجِعُ إِلَيْهِ فَيُخْبِرُهُ مَا قَالَتْ وَأَخَذَ ابْنُ عُمَرَ قَبْضَةً مِنْ حَصَى الْمَسْجِدِ يُقَلِّبُهَا فِي يَدِهِ حَتَّى رَجَعَ إِلَيْهِ الرَّسُولُ فَقَالَ قَالَتْ عَائِشَةُ صَدَقَ أَبُو هُرَيْرَةَ ‏.‏ فَضَرَبَ ابْنُ عُمَرَ بِالْحَصَى الَّذِي كَانَ فِي يَدِهِ الأَرْضَ ثُمَّ قَالَ لَقَدْ فَرَّطْنَا فِي قَرَارِيطَ كَثِيرَةٍ ‏.‏\hadithno{2195}\hadithtrans{Dawud b. 'Amir b. Sa'd b. Abu Waqqas reported on the authority of his father that while he was sitting along with 'Abdullah b. 'Umar, Khabbab, the owner of Maqsura, said:Ibn 'Umar, do you hear what Abu Huraira says that he heard the Messenger of Allah (ﷺ) say:" He who goes out with the bier when taken out from its residence and offers prayer for it and he then follows it till it is buried, he would have two qirats of reward, each qirat being equivalent to Uhud; and he who, after having offered prayer, (directly) came back would have his reward (as great) as Uhud"? Ibn 'Umar sent Khabbab to 'A'isha in order to ask her about the words of Abu Huraira (and also told him) to come back to him (Ibn 'Umar) and inform him what 'A'isha said. (In the meanwhile) Ibn 'Umar took up a handful of pebbles and turned them over in his hand till the messenger (Khabbab) came back to him and told (him) that 'A'isha testified (the statement of) Abu Huraira. Ibn 'Umar threw the pebbles he had in his hand on the ground and then said: We missed a large number of qirats}}
\hadithdefcmd{muslim}{2196}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي قَتَادَةُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ الْيَعْمَرِيِّ، عَنْ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَلَّى عَلَى جَنَازَةٍ فَلَهُ قِيرَاطٌ فَإِنْ شَهِدَ دَفْنَهَا فَلَهُ قِيرَاطَانِ الْقِيرَاطُ مِثْلُ أُحُدٍ ‏"‏ ‏.‏\hadithno{2196}\hadithtrans{Thauban, the freed slave of the Messenger of Allah (ﷺ) reported Allah's Messenger (ﷺ) as saying:He who offered prayer for the dead, for him is the reward of one qirat, and he who attended its burial, he would have two qirats as his reward. And qirat is equivalent to Uhud}}
\hadithdefcmd{muslim}{2197}{وَحَدَّثَنِي ابْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي قَالَ، وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا أَبَانٌ، كُلُّهُمْ عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏ وَفِي حَدِيثِ سَعِيدٍ وَهِشَامٍ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الْقِيرَاطِ فَقَالَ ‏ "‏ مِثْلُ أُحُدٍ ‏"‏ ‏.‏\hadithno{2197}\hadithtrans{This hadith has been narrated by Qatada with the same chain of transmitters. And in the hadith transmitted by Sa'id and Hisham, (the words are):" The Apostle of Allah (ﷺ) was asked about qirat, and he said: It is equivalent to Uhud}}
\hadithdefcmd{muslim}{2198}{حَدَّثَنَا الْحَسَنُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا سَلاَّمُ بْنُ أَبِي مُطِيعٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، - رَضِيعِ عَائِشَةَ - عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ مَيِّتٍ يُصَلِّي عَلَيْهِ أُمَّةٌ مِنَ الْمُسْلِمِينَ يَبْلُغُونَ مِائَةً كُلُّهُمْ يَشْفَعُونَ لَهُ إِلاَّ شُفِّعُوا فِيهِ ‏"‏ ‏.‏ قَالَ فَحَدَّثْتُ بِهِ شُعَيْبَ بْنَ الْحَبْحَابِ فَقَالَ حَدَّثَنِي بِهِ أَنَسُ بْنُ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2198}\hadithtrans{A'isha reported Allah's Apostle (ﷺ) saying:If a company of Muslims numbering one hundred pray over a dead person, all of them interceding for him, their intercession for him will be accepted}}
\hadithdefcmd{muslim}{2199}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَالْوَلِيدُ بْنُ شُجَاعٍ السَّكُونِيُّ، قَالَ الْوَلِيدُ حَدَّثَنِي وَقَالَ الآخَرَانِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أَبُو صَخْرٍ، عَنْ شَرِيكِ بْنِ عَبْدِ، اللَّهِ بْنِ أَبِي نَمِرٍ عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ مَاتَ ابْنٌ لَهُ بِقُدَيْدٍ أَوْ بِعُسْفَانَ فَقَالَ يَا كُرَيْبُ انْظُرْ مَا اجْتَمَعَ لَهُ مِنَ النَّاسِ ‏.‏ قَالَ فَخَرَجْتُ فَإِذَا نَاسٌ قَدِ اجْتَمَعُوا لَهُ فَأَخْبَرْتُهُ فَقَالَ تَقُولُ هُمْ أَرْبَعُونَ قَالَ نَعَمْ ‏.‏ قَالَ أَخْرِجُوهُ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ رَجُلٍ مُسْلِمٍ يَمُوتُ فَيَقُومُ عَلَى جَنَازَتِهِ أَرْبَعُونَ رَجُلاً لاَ يُشْرِكُونَ بِاللَّهِ شَيْئًا إِلاَّ شَفَّعَهُمُ اللَّهُ فِيهِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ مَعْرُوفٍ عَنْ شَرِيكِ بْنِ أَبِي نَمِرٍ عَنْ كُرَيْبٍ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{2199}\hadithtrans{Abdullah b. 'Abbas reported that his son died in Qudaid or 'Usfan. He said to Kuraib to see as to how many people had gathered there for his (funeral). He (Kuraib) said:So I went out and I informed him about the people who had gathered there. He (Ibn 'Abbas) said: Do you think they are forty? He (Kuraib) said: Yes. Ibn 'Abbas then said to them: Bring him (the dead body) out for I have heard Allah's Messenger (ﷺ) as saying: If any Muslim dies and forty men who associate nothing with Allah stand over his prayer (they offer prayer over him), Allah will accept them as intercessors for him}}
\hadithdefcmd{muslim}{2200}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ وَعَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ كُلُّهُمْ عَنِ ابْنِ عُلَيَّةَ، - وَاللَّفْظُ لِيَحْيَى قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، - أَخْبَرَنَا عَبْدُ الْعَزِيزِ، بْنُ صُهَيْبٍ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مُرَّ بِجَنَازَةٍ فَأُثْنِيَ عَلَيْهَا خَيْرٌ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ وَجَبَتْ وَجَبَتْ وَجَبَتْ ‏"‏ ‏.‏ وَمُرَّ بِجَنَازَةٍ فَأُثْنِيَ عَلَيْهَا شَرٌّ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ وَجَبَتْ وَجَبَتْ وَجَبَتْ ‏"‏ ‏.‏ قَالَ عُمَرُ فِدًى لَكَ أَبِي وَأُمِّي مُرَّ بِجَنَازَةٍ فَأُثْنِيَ عَلَيْهَا خَيْرًا فَقُلْتَ وَجَبَتْ وَجَبَتْ وَجَبَتْ ‏.‏ وَمُرَّ بِجَنَازَةٍ فَأُثْنِيَ عَلَيْهَا شَرٌّ فَقُلْتَ وَجَبَتْ وَجَبَتْ وَجَبَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَثْنَيْتُمْ عَلَيْهِ خَيْرًا وَجَبَتْ لَهُ الْجَنَّةُ وَمَنْ أَثْنَيْتُمْ عَلَيْهِ شَرًّا وَجَبَتْ لَهُ النَّارُ أَنْتُمْ شُهَدَاءُ اللَّهِ فِي الأَرْضِ أَنْتُمْ شُهَدَاءُ اللَّهِ فِي الأَرْضِ أَنْتُمْ شُهَدَاءُ اللَّهِ فِي الأَرْضِ ‏"‏ ‏.‏\hadithno{2200}\hadithtrans{Anas b. Malik reported:There passed a bier (being carried by people) and it was lauded in good terms. Upon this the Messenger of Allah (ﷺ) said: It has become certain, it has become certain, it has become certain. And there passed a bier and it was condemned in bad words. Upon this the Messenger of Allah (ﷺ) said: It has become certain, it has become certain, it has become certain. 'Umar said: May my father and mother be ransom for you! There passed a bier and it was praised in good terms, and you said: It has become certain, it has become certain, it has become certain. And there passed a bier and it was condemned in bad words, and you said: It has become certain, it has become certain, it has become certain. Upon this the Messenger of Allah (way peace be upon him) said: He whom you praised in good terms, Paradise has become certain for him, and he whom you condemned in bad words, Hell has become certain for him. You are Allah's witnesses in the earth, you are Allah's witnesses in the earth, you are Allah's witnesses in the earth}}
\hadithdefcmd{muslim}{2201}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ يَعْنِي ابْنَ زَيْدٍ، ح وَحَدَّثَنِي يَحْيَى بْنُ، يَحْيَى أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، كِلاَهُمَا عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ مُرَّ عَلَى النَّبِيِّ صلى الله عليه وسلم بِجَنَازَةٍ ‏.‏ فَذَكَرَ بِمَعْنَى حَدِيثِ عَبْدِ الْعَزِيزِ عَنْ أَنَسٍ غَيْرَ أَنَّ حَدِيثَ عَبْدِ الْعَزِيزِ أَتَمُّ ‏.‏\hadithno{2201}\hadithtrans{This hadith has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{2202}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ مُحَمَّدِ بْنِ عَمْرِو، بْنِ حَلْحَلَةَ عَنْ مَعْبَدِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِي قَتَادَةَ بْنِ رِبْعِيٍّ، أَنَّهُ كَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مُرَّ عَلَيْهِ بِجَنَازَةٍ فَقَالَ ‏"‏ مُسْتَرِيحٌ وَمُسْتَرَاحٌ مِنْهُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَا الْمُسْتَرِيحُ وَالْمُسْتَرَاحُ مِنْهُ ‏.‏ فَقَالَ ‏"‏ الْعَبْدُ الْمُؤْمِنُ يَسْتَرِيحُ مِنْ نَصَبِ الدُّنْيَا وَالْعَبْدُ الْفَاجِرُ يَسْتَرِيحُ مِنْهُ الْعِبَادُ وَالْبِلاَدُ وَالشَّجَرُ وَالدَّوَابُّ ‏"‏ ‏.‏\hadithno{2202}\hadithtrans{Qatada b. Rib'i reported Allah's Messenger (ﷺ) as saying:Whenever a bier passed before him, he said: He is the one to find relief and the one with (the departure of him) other will find relief. They said: Apostle of Allah, who is al-Mustarih and al-Mustarah? Upon this he said: The believing servant finds relief from the troubles of the world, and in the death of a wicked person, the people, towns, trees and animals find rellef}}
\hadithdefcmd{muslim}{2203}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، جَمِيعًا عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنِ ابْنٍ لِكَعْبِ بْنِ مَالِكٍ، عَنْ أَبِي قَتَادَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَفِي حَدِيثِ يَحْيَى بْنِ سَعِيدٍ ‏ "‏ يَسْتَرِيحُ مِنْ أَذَى الدُّنْيَا وَنَصَبِهَا إِلَى رَحْمَةِ اللَّهِ ‏"‏ ‏.‏\hadithno{2203}\hadithtrans{In the hadith transmitted by Yahya b. Sa'id on the authority of Qatada (the words are):(The believing servant) finds relief from the troubles of the world and its hardships and (gets into) the Mercy of Allah}}
\hadithdefcmd{muslim}{2204}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَعَى لِلنَّاسِ النَّجَاشِيَ فِي الْيَوْمِ الَّذِي مَاتَ فِيهِ فَخَرَجَ بِهِمْ إِلَى الْمُصَلَّى وَكَبَّرَ أَرْبَعَ تَكْبِيرَاتٍ ‏.‏\hadithno{2204}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) gave the people news of the death of Negus on the day he died, and he took them out to the place of prayer and observed four takbirs}}
\hadithdefcmd{muslim}{2205}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ حَدَّثَنِي عُقَيْلُ، بْنُ خَالِدٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَنَّهُمَا حَدَّثَاهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ نَعَى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم النَّجَاشِيَ صَاحِبَ الْحَبَشَةِ فِي الْيَوْمِ الَّذِي مَاتَ فِيهِ فَقَالَ ‏ "‏ اسْتَغْفِرُوا لأَخِيكُمْ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ وَحَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ أَنَّ أَبَا هُرَيْرَةَ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَفَّ بِهِمْ بِالْمُصَلَّى فَصَلَّى فَكَبَّرَ عَلَيْهِ أَرْبَعَ تَكْبِيرَاتٍ ‏.‏\hadithno{2205}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) gave us the news of the death of Negus, the ruler of Abyssinia, on the day when he died, and he said (to us): Beg pardon for your brother. Ibn Shihab said that Sa'id b. Musayyib had told that Abu Huraira had narrated to him that the Messenger of Allah (ﷺ) drew them up in a row in a place of prayer, and offered prayer and recited four takbirs for him}}
\hadithdefcmd{muslim}{2206}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَحَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالُوا حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، كَرِوَايَةِ عُقَيْلٍ بِالإِسْنَادَيْنِ جَمِيعًا ‏.‏\hadithno{2206}\hadithtrans{This hadith is narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{2207}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ سَلِيمِ بْنِ حَيَّانٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ مِينَاءَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى\hadithno{2207}\hadithtrans{Jabir b. 'Abdullah reported that the Messenger of Allah (ﷺ) offered prayer for Ashama, the Negus, and recited four takbirs}}
\hadithdefcmd{muslim}{2208}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَاتَ الْيَوْمَ عَبْدٌ لِلَّهِ صَالِحٌ أَصْحَمَةُ ‏"‏ ‏.‏ فَقَامَ فَأَمَّنَا وَصَلَّى عَلَيْهِ ‏.‏\hadithno{2208}\hadithtrans{Jabir b. 'Abdullah reported Allah's Messenger (ﷺ) as saying:There died today the pious servant of Allah, Ashama. So he stood up and led us in (funeral prayer) over him}}
\hadithdefcmd{muslim}{2209}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ، بْنِ عَبْدِ اللَّهِ ح . وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا ابْنُ عُلَيَّةَ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي، الزُّبَيْرِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَخًا لَكُمْ قَدْ مَاتَ فَقُومُوا فَصَلُّوا عَلَيْهِ ‏"‏ ‏.‏ قَالَ فَقُمْنَا فَصَفَّنَا صَفَّيْنِ ‏.‏\hadithno{2209}\hadithtrans{Jabir b. 'Abdullah reported Allah's Messenger (ﷺ) as saying:A brother of yours has died, so stand up and offer prayer over him. So we stood up and drew ourselves up into two rows}}
\hadithdefcmd{muslim}{2210}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، ح وَحَدَّثَنَا يَحْيَى، بْنُ أَيُّوبَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَخًا لَكُمْ قَدْ مَاتَ فَقُومُوا فَصَلُّوا عَلَيْهِ ‏"‏ ‏.‏ يَعْنِي النَّجَاشِيَ وَفِي رِوَايَةِ زُهَيْرٍ ‏"‏ إِنَّ أَخَاكُمْ ‏"‏ ‏.‏\hadithno{2210}\hadithtrans{Imran b. Husain reported Allah's Messenger (ﷺ) as saying:A brother of yours has died; so stand up and offer prayer for him, i. e. Negus. And in the hadith transmitted by Zubair (the words are):" Your brother}}
\hadithdefcmd{muslim}{2211}{حَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ، إِدْرِيسَ عَنِ الشَّيْبَانِيِّ، عَنِ الشَّعْبِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى عَلَى قَبْرٍ بَعْدَ مَا دُفِنَ فَكَبَّرَ عَلَيْهِ أَرْبَعًا ‏.‏ قَالَ الشَّيْبَانِيُّ فَقُلْتُ لِلشَّعْبِيِّ مَنْ حَدَّثَكَ بِهَذَا قَالَ الثِّقَةُ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ ‏.‏ هَذَا لَفْظُ حَدِيثِ حَسَنٍ وَفِي رِوَايَةِ ابْنِ نُمَيْرٍ قَالَ انْتَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى قَبْرٍ رَطْبٍ فَصَلَّى عَلَيْهِ وَصَفُّوا خَلْفَهُ وَكَبَّرَ أَرْبَعًا ‏.‏ قُلْتُ لِعَامِرٍ مَنْ حَدَّثَكَ قَالَ الثِّقَةُ مَنْ شَهِدَهُ ابْنُ عَبَّاسٍ ‏.‏\hadithno{2211}\hadithtrans{Sha'bi reported that the Messenger of Allah (ﷺ) observed prayer over a grave after the dead was buried and he recited four takbirs over him. Shaibani said:I said to Sha'bi: Who narrated it to you? He said: An authentic one, 'Abdullah b. 'Abbas. This is the word of a hasan hadith. In the narration of Ibn Numair (the words are): The Messenger of Allah (ﷺ) went to the grave which had been newly prepared and prayed over it, and they also prayed who were behind him and he recited four takbirs. I said to 'Amir: Who narrated it to you? He said: An authentic one who saw him, i e. Ibn 'Abbas}}
\hadithdefcmd{muslim}{2212}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، ح وَحَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، كُلُّ هَؤُلاَءِ عَنِ الشَّيْبَانِيِّ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ وَلَيْسَ فِي حَدِيثِ أَحَدٍ مِنْهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَبَّرَ عَلَيْهِ أَرْبَعًا ‏.‏\hadithno{2212}\hadithtrans{This hadith has been narrated through another chain of transmitters, but in one of them (these words are found):" The Apostle of Allah (ﷺ) recited four takbirs}}
\hadithdefcmd{muslim}{2213}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، جَمِيعًا عَنْ وَهْبِ بْنِ جَرِيرٍ، عَنْ شُعْبَةَ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، ح وَحَدَّثَنِي أَبُو غَسَّانَ، مُحَمَّدُ بْنُ عَمْرٍو الرَّازِيُّ حَدَّثَنَا يَحْيَى بْنُ الضُّرَيْسِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ أَبِي حَصِينٍ، كِلاَهُمَا عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي صَلاَتِهِ عَلَى الْقَبْرِ نَحْوَ حَدِيثِ الشَّيْبَانِيِّ ‏.‏ لَيْسَ فِي حَدِيثِهِمْ وَكَبَّرَ أَرْبَعًا ‏.‏\hadithno{2213}\hadithtrans{The hadith as narrated by Shaibani has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{2214}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ عَرْعَرَةَ السَّامِيُّ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى عَلَى قَبْرٍ ‏.‏\hadithno{2214}\hadithtrans{Anas reported that the Messenger of Allah (ﷺ) observed prayer on the grave}}
\hadithdefcmd{muslim}{2215}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَأَبُو كَامِلٍ فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ - وَاللَّفْظُ لأَبِي كَامِلٍ - قَالاَ حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي، هُرَيْرَةَ أَنَّ امْرَأَةً، سَوْدَاءَ كَانَتْ تَقُمُّ الْمَسْجِدَ - أَوْ شَابًّا - فَفَقَدَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَأَلَ عَنْهَا - أَوْ عَنْهُ - فَقَالُوا مَاتَ ‏.‏ قَالَ ‏"‏ أَفَلاَ كُنْتُمْ آذَنْتُمُونِي ‏"‏ ‏.‏ قَالَ فَكَأَنَّهُمْ صَغَّرُوا أَمْرَهَا - أَوْ أَمْرَهُ - فَقَالَ ‏"‏ دُلُّونِي عَلَى قَبْرِهِ ‏"‏ ‏.‏ فَدَلُّوهُ فَصَلَّى عَلَيْهَا ثُمَّ قَالَ ‏"‏ إِنَّ هَذِهِ الْقُبُورَ مَمْلُوءَةٌ ظُلْمَةً عَلَى أَهْلِهَا وَإِنَّ اللَّهَ عَزَّ وَجَلَّ يُنَوِّرُهَا لَهُمْ بِصَلاَتِي عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{2215}\hadithtrans{It is narrated on the authority of Abu Huraira that a dark-complexioned woman (or a youth) used to sweep the mosque. The Messenger of Allah (ﷺ) missed her (or him) and inquired about her (or him). The people told him that she (or he) had died. He asked why they did not inform him, and it appears as if they had treated her (or him) or her (or his) affairs as of little account. He (the Holy Prophet) said:Lead me to her (or his) grave. They led him to that place and he said prayer over her (or him) and then remarked: Verily, these graves are full of darkness for their dwellers. Verily, the Mighty and Glorious Allah illuminates them for their occupants by reason of my prayer over them}}
\hadithdefcmd{muslim}{2216}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالُوا حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، - وَقَالَ أَبُو بَكْرٍ عَنْ شُعْبَةَ، - عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ أَبِي لَيْلَى قَالَ كَانَ زَيْدٌ يُكَبِّرُ عَلَى جَنَائِزِنَا أَرْبَعًا وَإِنَّهُ كَبَّرَ عَلَى جَنَازَةٍ خَمْسًا فَسَأَلْتُهُ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكَبِّرُهَا ‏.‏\hadithno{2216}\hadithtrans{It is narrated on the authority of 'Abd al-Rahman b. Abu Laila that Zaid used to recite four takbirs on our funerals and he recited five takbirs on one funeral. I asked him the reason (for this variation), to which he replied:The Messenger of Allah (ﷺ) recited thus}}
\hadithdefcmd{muslim}{2217}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنْ عَامِرِ بْنِ رَبِيعَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا لَهَا حَتَّى تُخَلِّفَكُمْ أَوْ تُوضَعَ ‏"‏ ‏.‏\hadithno{2217}\hadithtrans{It is narrated on the authority of 'Amir Ibn Rabi'a (may Allah be pleased with him) that the Prophet (ﷺ) said:Whenever you see a funeral procession, stand up for that until it moves away or is lowered on the ground}}
\hadithdefcmd{muslim}{2218}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنِي حَرْمَلَةُ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، جَمِيعًا عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِ يُونُسَ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ حَدَّثَنَا لَيْثٌ ح وَحَدَّثَنَا ابْنُ رُمْحٍ أَخْبَرَنَا اللَّيْثُ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنْ عَامِرِ بْنِ رَبِيعَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَى أَحَدُكُمُ الْجَنَازَةَ فَإِنْ لَمْ يَكُنْ مَاشِيًا مَعَهَا فَلْيَقُمْ حَتَّى تُخَلِّفَهُ أَوْ تُوضَعَ مِنْ قَبْلِ أَنْ تُخَلِّفَهُ ‏"‏ ‏.‏\hadithno{2218}\hadithtrans{It is narrated on the authority of 'Amir ibn Rabi'a (may Allah be pleased with him) that the Prophet (ﷺ) said:Should any one of you come across a funeral procession, and if he does not intend to accompany it, he must stand up until it passes by him or is placed upon the ground before it passes him}}
\hadithdefcmd{muslim}{2219}{وَحَدَّثَنِي أَبُو كَامِلٍ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا إِسْمَاعِيلُ، جَمِيعًا عَنْ أَيُّوبَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، كُلُّهُمْ عَنْ نَافِعٍ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ اللَّيْثِ بْنِ سَعْدٍ غَيْرَ أَنَّ حَدِيثَ، ابْنِ جُرَيْجٍ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَى أَحَدُكُمُ الْجَنَازَةَ فَلْيَقُمْ حِينَ يَرَاهَا حَتَّى تُخَلِّفَهُ إِذَا كَانَ غَيْرَ مُتَّبِعِهَا ‏"‏ ‏.‏\hadithno{2219}\hadithtrans{It is reported on the authority of Ibn Juraij that the Prophet (ﷺ) said:Should anyone amongst you see a bier he must stand up so long as it is within sight in case he does not intend to follow it}}
\hadithdefcmd{muslim}{2220}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اتَّبَعْتُمْ جَنَازَةً فَلاَ تَجْلِسُوا حَتَّى تُوضَعَ ‏"‏ ‏.‏\hadithno{2220}\hadithtrans{It is narrated on the authority of Abu Sa'id al-Khudri that the Prophet (ﷺ) said:When you follow a bier, do not sit until it is placed on the (ground)}}
\hadithdefcmd{muslim}{2221}{وَحَدَّثَنِي سُرَيْجُ بْنُ يُونُسَ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مُعَاذُ بْنُ، هِشَامٍ حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي، سَعِيدٍ الْخُدْرِيِّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا فَمَنْ تَبِعَهَا فَلاَ يَجْلِسْ حَتَّى تُوضَعَ ‏"‏ ‏.‏\hadithno{2221}\hadithtrans{It is narrated on the authority of Abu Sa'id al-Khudri that the Prophet (ﷺ) said:Whenever you come across a bier you should stand up, and he who follows it should not sit down till it is placed on the ground}}
\hadithdefcmd{muslim}{2222}{وَحَدَّثَنِي سُرَيْجُ بْنُ يُونُسَ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ مِقْسَمٍ، عَنْ جَابِرِ، بْنِ عَبْدِ اللَّهِ قَالَ مَرَّتْ جَنَازَةٌ فَقَامَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَقُمْنَا مَعَهُ فَقُلْنَا يَا رَسُولَ اللَّهِ إِنَّهَا يَهُودِيَّةٌ ‏.‏ فَقَالَ ‏ "‏ إِنَّ الْمَوْتَ فَزَعٌ فَإِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا ‏"‏ ‏.‏\hadithno{2222}\hadithtrans{It is narrated on the authority of Jabir ibn 'Abdullah:There passed a bier and the Prophet (ﷺ) stood up for it and we also stood up along with him. We said: Messenger of Allah, that was the bier of a Jewess. Upon this he remarked: Verily, death is a matter of consternation, so whenever you come across a bier stand up}}
\hadithdefcmd{muslim}{2223}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ قَامَ النَّبِيُّ صلى الله عليه وسلم لِجَنَازَةٍ مَرَّتْ بِهِ حَتَّى تَوَارَتْ ‏.‏\hadithno{2223}\hadithtrans{Ibn Juraij told me that Abu Zubair heard Jabir say that the Prophet (ﷺ) kept standing for a bier until it disappeared}}
\hadithdefcmd{muslim}{2224}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ أَيْضًا أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ قَامَ النَّبِيُّ صلى الله عليه وسلم وَأَصْحَابُهُ لِجَنَازَةِ يَهُودِيٍّ حَتَّى تَوَارَتْ ‏.‏\hadithno{2224}\hadithtrans{Again Abu Zubair heard Jabir say that the Prophet (ﷺ) and his Companions kept standing for a bier of a Jew until it disappeared from sight}}
\hadithdefcmd{muslim}{2226}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنِ ابْنِ أَبِي لَيْلَى، أَنَّ قَيْسَ بْنَ سَعْدٍ، وَسَهْلَ بْنَ حُنَيْفٍ، كَانَا بِالْقَادِسِيَّةِ فَمَرَّتْ بِهِمَا جَنَازَةٌ فَقَامَا فَقِيلَ لَهُمَا إِنَّهَا مِنْ أَهْلِ الأَرْضِ ‏.‏ فَقَالاَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّتْ بِهِ جَنَازَةٌ فَقَامَ فَقِيلَ إِنَّهُ يَهُودِيٌّ ‏.‏ فَقَالَ ‏ "‏ أَلَيْسَتْ نَفْسًا ‏"‏ ‏.‏ وَحَدَّثَنِيهِ الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، بِهَذَا الإِسْنَادِ وَفِيهِ فَقَالاَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَرَّتْ عَلَيْنَا جَنَازَةٌ ‏.‏\hadithno{2226}\hadithtrans{It is narrated on the authority of Ibn Abu Laila that while Qais b. Sa'd and Sahl b. Hunaif were both in Qadislyya a bier passed by them and they both stood up. They were told that it was the bier of one of the people of the land (non-Muslim). They said that a bier passed before the Prophet (ﷺ) and he stood up. He was told that he (the dead man) was a Jew. Upon this he remarked:Was he not a human being or did he not have a soul? And in the hadith narrated by 'Amr b. Murra with the same chain of transmitters, (the words) are:" There passed a bier before us}}
\hadithdefcmd{muslim}{2227}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ وَاقِدِ بْنِ عَمْرِو بْنِ سَعْدِ بْنِ مُعَاذٍ، أَنَّهُ قَالَ رَآنِي نَافِعُ بْنُ جُبَيْرٍ وَنَحْنُ فِي جَنَازَةٍ قَائِمًا وَقَدْ جَلَسَ يَنْتَظِرُ أَنْ تُوضَعَ الْجَنَازَةُ فَقَالَ لِي مَا يُقِيمُكَ فَقُلْتُ أَنْتَظِرُ أَنْ تُوضَعَ الْجَنَازَةُ لِمَا يُحَدِّثُ أَبُو سَعِيدٍ الْخُدْرِيُّ ‏.‏ فَقَالَ نَافِعٌ فَإِنَّ مَسْعُودَ بْنَ الْحَكَمِ حَدَّثَنِي عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ أَنَّهُ قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَعَدَ ‏.‏\hadithno{2227}\hadithtrans{It is narrated on the authority of Waqid:Nafi' b. Jubair saw me and we were standing for a bier, while he was sitting and waiting for the bier to be placed on the ground. He said to me: What makes you keep standing? I said: I am waiting that the bier may be placed on the ground (and I am doing that) on the hadith narrated to me by Abu Sa'id al-Khudri. Upon this Nafi' said: Verily, Mas'ud b. Hakam reported to me on the authority of Hadrat 'Ali b. Abu Talib that the Prophet (ﷺ) stood up first (for a bier) and then sat down}}
\hadithdefcmd{muslim}{2228}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ الثَّقَفِيِّ، - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا عَبْدُ الْوَهَّابِ، - قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، قَالَ أَخْبَرَنِي وَاقِدُ، بْنُ عَمْرِو بْنِ سَعْدِ بْنِ مُعَاذٍ الأَنْصَارِيُّ أَنَّ نَافِعَ بْنَ جُبَيْرٍ، أَخْبَرَهُ أَنَّ مَسْعُودَ بْنَ الْحَكَمِ الأَنْصَارِيَّ أَخْبَرَهُ أَنَّهُ، سَمِعَ عَلِيَّ بْنَ أَبِي طَالِبٍ، يَقُولُ فِي شَأْنِ الْجَنَائِزِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ ثُمَّ قَعَدَ ‏.‏ وَإِنَّمَا حَدَّثَ بِذَلِكَ لأَنَّ نَافِعَ بْنَ جُبَيْرٍ رَأَى وَاقِدَ بْنَ عَمْرٍو قَامَ حَتَّى وُضِعَتِ الْجَنَازَةُ ‏.‏\hadithno{2228}\hadithtrans{Mas'ud b. al-Hakam al-Ansari informed Nafi' that he had heard Hadrat 'Ali (may Allah be pleased with him), son of Abu Talib, say about the biers:Verily, the Prophet (ﷺ) used to stand first but later on kept sitting; but it is also narrated that Nafi' ibn Jubair saw Waqid b. 'Amr standing for a bier till it was placed down}}
\hadithdefcmd{muslim}{2229}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{2229}\hadithtrans{This hadith has been narrated by Yahya b. Sa'id with the same chain of transmitters}}
\hadithdefcmd{muslim}{2230}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ، بْنِ الْمُنْكَدِرِ قَالَ سَمِعْتُ مَسْعُودَ بْنَ الْحَكَمِ، يُحَدِّثُ عَنْ عَلِيٍّ، قَالَ رَأَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ فَقُمْنَا وَقَعَدَ فَقَعَدْنَا ‏.‏ يَعْنِي فِي الْجَنَازَةِ ‏.‏\hadithno{2230}\hadithtrans{It is narrated on the authority of Muhammad b. Munkadir that he said:I heard from Mas'ud b. al-Hakam who narrated it on the authority of Hadrat 'Ali that he said: We saw the Prophet (ﷺ) stood up for a (bier) and we also stood up; he sat down and we too sat down}}
\hadithdefcmd{muslim}{2231}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{2231}\hadithtrans{This hadith has been narrated by Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{2233}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ حَبِيبِ بْنِ عُبَيْدٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، سَمِعَهُ يَقُولُ سَمِعْتُ عَوْفَ بْنَ مَالِكٍ، يَقُولُ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى جَنَازَةٍ فَحَفِظْتُ مِنْ دُعَائِهِ وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لَهُ وَارْحَمْهُ وَعَافِهِ وَاعْفُ عَنْهُ وَأَكْرِمْ نُزُلَهُ وَوَسِّعْ مُدْخَلَهُ وَاغْسِلْهُ بِالْمَاءِ وَالثَّلْجِ وَالْبَرَدِ وَنَقِّهِ مِنَ الْخَطَايَا كَمَا نَقَّيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ وَأَبْدِلْهُ دَارًا خَيْرًا مِنْ دَارِهِ وَأَهْلاً خَيْرًا مِنْ أَهْلِهِ وَزَوْجًا خَيْرًا مِنْ زَوْجِهِ وَأَدْخِلْهُ الْجَنَّةَ وَأَعِذْهُ مِنْ عَذَابِ الْقَبْرِ أَوْ مِنْ عَذَابِ النَّارِ ‏"‏ ‏.‏ قَالَ حَتَّى تَمَنَّيْتُ أَنْ أَكُونَ أَنَا ذَلِكَ الْمَيِّتَ ‏.‏ قَالَ وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ جُبَيْرٍ حَدَّثَهُ عَنْ أَبِيهِ عَنْ عَوْفِ بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ هَذَا الْحَدِيثِ أَيْضًا ‏.‏\hadithno{2233}\hadithtrans{Jubair b. Nufair says:I heard it from 'Auf b. Malik that the Prophet (ﷺ) said prayer on the dead body, and I remembered his prayer:" O Allah! forgive him, have mercy upon him, give him peace and absolve him. Receive him with honour and make his grave spacious; wash him with water, snow and hail. Cleanse him from faults as Thou wouldst cleanse a white garment from impurity. Requite him with an abode more excellent than his abode, with a family better than his family, and with a mate better than his mate. Admit him to the Garden, and protect him from the torment of the grave and the torment of the Fire." ('Auf bin Malik) said: I earnestly desired that I were this dead body}}
\hadithdefcmd{muslim}{2234}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا مُعَاوِيَةُ بْنُ، صَالِحٍ بِالإِسْنَادَيْنِ جَمِيعًا ‏.‏ نَحْوَ حَدِيثِ ابْنِ وَهْبٍ ‏.‏\hadithno{2234}\hadithtrans{A hadith like this has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{2235}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ حُسَيْنِ بْنِ، ذَكْوَانَ قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ صَلَّيْتُ خَلْفَ النَّبِيِّ صلى الله عليه وسلم وَصَلَّى عَلَى أُمِّ كَعْبٍ مَاتَتْ وَهِيَ نُفَسَاءُ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلصَّلاَةِ عَلَيْهَا وَسَطَهَا ‏.‏\hadithno{2235}\hadithtrans{Samura b. Jundub said:I prayed behind the Messenger of Allah (ﷺ) and he prayed for a woman who had died in the state of delivery. He stood in front of her waist}}
\hadithdefcmd{muslim}{2236}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، وَيَزِيدُ بْنُ هَارُونَ، ح وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، وَالْفَضْلُ بْنُ مُوسَى، كُلُّهُمْ عَنْ حُسَيْنٍ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرُوا أُمَّ كَعْبٍ ‏.‏\hadithno{2236}\hadithtrans{This hadith has been narrated by Husain with the same chain of transmitters, but no mention is made of Umm Ka'b}}
\hadithdefcmd{muslim}{2237}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَعُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حُسَيْنٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، قَالَ قَالَ سَمُرَةُ بْنُ جُنْدُبٍ لَقَدْ كُنْتُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم غُلاَمًا فَكُنْتُ أَحْفَظُ عَنْهُ فَمَا يَمْنَعُنِي مِنَ الْقَوْلِ إِلاَّ أَنَّ هَا هُنَا رِجَالاً هُمْ أَسَنُّ مِنِّي وَقَدْ صَلَّيْتُ وَرَاءَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى امْرَأَةٍ مَاتَتْ فِي نِفَاسِهَا فَقَامَ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الصَّلاَةِ وَسَطَهَا ‏.‏ وَفِي رِوَايَةِ ابْنِ الْمُثَنَّى قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ قَالَ فَقَامَ عَلَيْهَا لِلصَّلاَةِ وَسَطَهَا ‏.‏\hadithno{2237}\hadithtrans{Samura b. Jundub said:I was a young boy during the time of the Prophet (ﷺ) and I retained in my mind (what I learnt from him), and nothing restrained me from speaking except the fact that there were persons far more advanced in age than I. Verily, I said prayer behind the Messenger of Allah (ﷺ) over a woman who had died in the state of delivery, and the Messenger of Allah (ﷺ) stood up to say prayer in front of the middle part of her body. And in the tradition narrated on the authority of Ibn Muthanna the words are:" (The Holy Prophet) stood in the middle part of her body for offering prayer for her}}
\hadithdefcmd{muslim}{2238}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ - وَاللَّفْظُ لِيَحْيَى - قَالَ أَبُو بَكْرٍ حَدَّثَنَا وَقَالَ، يَحْيَى أَخْبَرَنَا وَكِيعٌ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ، سَمُرَةَ قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِفَرَسٍ مُعْرَوْرًى فَرَكِبَهُ حِينَ انْصَرَفَ مِنْ جَنَازَةِ ابْنِ الدَّحْدَاحِ وَنَحْنُ نَمْشِي حَوْلَهُ ‏.‏\hadithno{2238}\hadithtrans{It is reported on the authority of Jabir ibn Samura that an unsaddled horse was brought to the Prophet (ﷺ) and he rode on it when he returned after having offered the funeral prayer of Ibn Dahdah and we walked on foot around him}}
\hadithdefcmd{muslim}{2239}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى ابْنِ الدَّحْدَاحِ ثُمَّ أُتِيَ بِفَرَسٍ عُرْىٍ فَعَقَلَهُ رَجُلٌ فَرَكِبَهُ فَجَعَلَ يَتَوَقَّصُ بِهِ وَنَحْنُ نَتَّبِعُهُ نَسْعَى خَلْفَهُ - قَالَ - فَقَالَ رَجُلٌ مِنَ الْقَوْمِ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ كَمْ مِنْ عِذْقٍ مُعَلَّقٍ - أَوْ مُدَلًّى - فِي الْجَنَّةِ لاِبْنِ الدَّحْدَاحِ ‏"‏ ‏.‏ أَوْ قَالَ شُعْبَةُ ‏"‏ لأَبِي الدَّحْدَاحِ ‏"‏ ‏.‏\hadithno{2239}\hadithtrans{Jabir ibn Samura reported that the Prophet (ﷺ) said (funeral) prayer on Ibn Dahdah:then an unsaddled horse was brought to him and a person hobbled it, and he (the Messenger of Allah) rode upon it and it bounded and we followed it and ran after it. One of the people said that the Prophet (ﷺ) remarked: How many among hanging bunches in the Paradise are meant for Ibn Dahdah?}}
\hadithdefcmd{muslim}{2240}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الْمِسْوَرِيُّ، عَنْ إِسْمَاعِيلَ بْنِ، مُحَمَّدِ بْنِ سَعْدٍ عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، أَنَّ سَعْدَ بْنَ أَبِي وَقَّاصٍ، قَالَ فِي مَرَضِهِ الَّذِي هَلَكَ فِيهِ الْحَدُوا لِي لَحْدًا وَانْصِبُوا عَلَىَّ اللَّبِنَ نَصْبًا كَمَا صُنِعَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2240}\hadithtrans{Amir b. Sa'd b. Abu Waqqas told that Sa'd b. Abu Waqqas said during his illness of which he died:" Make a niche for me in the side of the grave and set up bricks over me as was done in case of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{2241}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، وَوَكِيعٌ، جَمِيعًا عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا يَحْيَى، بْنُ سَعِيدٍ حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا أَبُو جَمْرَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جُعِلَ فِي قَبْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَطِيفَةٌ حَمْرَاءُ ‏.‏ قَالَ مُسْلِمٌ أَبُو جَمْرَةَ اسْمُهُ نَصْرُ بْنُ عِمْرَانَ وَأَبُو التَّيَّاحِ اسْمُهُ يَزِيدُ بْنُ حُمَيْدٍ مَاتَا بِسَرَخْسَ ‏.‏\hadithno{2241}\hadithtrans{Ibn 'Abbas said that a piece of red stuff was put in the grave of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{2242}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرٍو حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، ح وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عَمْرُو بْنُ الْحَارِثِ، - فِي رِوَايَةِ أَبِي الطَّاهِرِ - أَنَّ أَبَا عَلِيٍّ الْهَمْدَانِيَّ، حَدَّثَهُ - وَفِي، رِوَايَةِ هَارُونَ - أَنَّ ثُمَامَةَ بْنَ، شُفَىٍّ حَدَّثَهُ قَالَ كُنَّا مَعَ فَضَالَةَ بْنِ عُبَيْدٍ بِأَرْضِ الرُّومِ بِرُودِسَ فَتُوُفِّيَ صَاحِبٌ لَنَا فَأَمَرَ فَضَالَةُ بْنُ عُبَيْدٍ بِقَبْرِهِ فَسُوِّيَ ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُ بِتَسْوِيَتِهَا ‏.‏\hadithno{2242}\hadithtrans{Thumama b. Shafayy reported:When we were with Fadala b. 'Ubaid in the country of the Romans at a place (known as) Rudis, a friend of ours died. Fadala b. 'Ubaid ordered to prepare a grave for him and then it was levelled; and then he said: I heard the Messenger of Allah (ﷺ) commanding (us) to level the grave}}
\hadithdefcmd{muslim}{2244}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي، الْهَيَّاجِ الأَسَدِيِّ قَالَ قَالَ لِي عَلِيُّ بْنُ أَبِي طَالِبٍ أَلاَّ أَبْعَثُكَ عَلَى مَا بَعَثَنِي عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ لاَ تَدَعَ تِمْثَالاً إِلاَّ طَمَسْتَهُ وَلاَ قَبْرًا مُشْرِفًا إِلاَّ سَوَّيْتَهُ ‏.‏ وَحَدَّثَنِيهِ أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي حَبِيبٌ، بِهَذَا الإِسْنَادِ وَقَالَ وَلاَ صُورَةً إِلاَّ طَمَسْتَهَا ‏.‏\hadithno{2244}\hadithtrans{Abu'l-Hayyaj al-Asadi told that 'Ali (b. Abu Talib) said to him:Should I not send you on the same mission as Allah's Messenger (ﷺ) sent me? Do not leave an image without obliterating it, or a high grave without levelling It. This hadith has been reported by Habib with the same chain of transmitters and he said: (Do not leave) a picture without obliterating it}}
\hadithdefcmd{muslim}{2245}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي، الزُّبَيْرِ عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُجَصَّصَ الْقَبْرُ وَأَنْ يُقْعَدَ عَلَيْهِ وَأَنْ يُبْنَى عَلَيْهِ ‏.‏\hadithno{2245}\hadithtrans{Jabir said:Allah's Messenger (ﷺ) forbade that the graves should be plastered or they be used as sitting places (for the people), or a building should be built over them}}
\hadithdefcmd{muslim}{2246}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، جَمِيعًا عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ، اللَّهِ يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{2246}\hadithtrans{A hadith like this has been transmitted on the authority of Jabir b. 'Abdullah}}
\hadithdefcmd{muslim}{2247}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نُهِيَ عَنْ تَقْصِيصِ الْقُبُورِ، ‏.‏\hadithno{2247}\hadithtrans{Jabir said that he was forbidden to plaster graves}}
\hadithdefcmd{muslim}{2248}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَجْلِسَ أَحَدُكُمْ عَلَى جَمْرَةٍ فَتُحْرِقَ ثِيَابَهُ فَتَخْلُصَ إِلَى جِلْدِهِ خَيْرٌ لَهُ مِنْ أَنْ يَجْلِسَ عَلَى قَبْرٍ ‏"‏ ‏.‏\hadithno{2248}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:It is better that one of you should sit on live coals which would burn his clothing and come in contact with his skin than that he should sit on a grave}}
\hadithdefcmd{muslim}{2249}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ ح وَحَدَّثَنِيهِ عَمْرٌو، النَّاقِدُ حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ.‏\hadithno{2249}\hadithtrans{A hadith like this has been narrated by Suhail with the same chain of transmitters}}
\hadithdefcmd{muslim}{2250}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ ابْنِ جَابِرٍ، عَنْ بُسْرِ، بْنِ عُبَيْدِ اللَّهِ عَنْ وَاثِلَةَ، عَنْ أَبِي مَرْثَدٍ الْغَنَوِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَجْلِسُوا عَلَى الْقُبُورِ وَلاَ تُصَلُّوا إِلَيْهَا ‏"‏ ‏.‏\hadithno{2250}\hadithtrans{Abu Marthad al-Ghanawi reported Allah's Messenger (ﷺ) as saying:Do not sit on the graves and do not pray facing towards them}}
\hadithdefcmd{muslim}{2251}{وَحَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ الْبَجَلِيُّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، عَنْ أَبِي مَرْثَدٍ الْغَنَوِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُصَلُّوا إِلَى الْقُبُورِ وَلاَ تَجْلِسُوا عَلَيْهَا‏"‏ ‏.‏\hadithno{2251}\hadithtrans{Abu Marthad al-Ghanawi reported Allah's Messenger (ﷺ) as saying:Do not pray facing towards the graves, and do not sit on them}}
\hadithdefcmd{muslim}{2252}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، - وَاللَّفْظُ لإِسْحَاقَ - قَالَ عَلِيٌّ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَبْدِ الْوَاحِدِ بْنِ حَمْزَةَ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَنَّ عَائِشَةَ، أَمَرَتْ أَنْ يُمَرَّ، بِجَنَازَةِ سَعْدِ بْنِ أَبِي وَقَّاصٍ فِي الْمَسْجِدِ فَتُصَلِّيَ عَلَيْهِ فَأَنْكَرَ النَّاسُ ذَلِكَ عَلَيْهَا فَقَالَتْ مَا أَسْرَعَ مَا نَسِيَ النَّاسُ مَا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى سُهَيْلِ ابْنِ الْبَيْضَاءِ إِلاَّ فِي الْمَسْجِدِ ‏.‏\hadithno{2252}\hadithtrans{Abbad b. 'Abdullah b. Zubair reported that 'A'isha ordered the bier of Sa'd b. Abu Waqqas to be brought into the mosque so that she should pray for him. The people disapproved this (act) of hers. She said:How soon the people have forgotten that the Messenger of Allah (ﷺ) offered not the funeral prayer of Suhail b al-Baida' but in a mosque}}
\hadithdefcmd{muslim}{2253}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ عَبْدِ الْوَاحِدِ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، يُحَدِّثُ عَنْ عَائِشَةَ، أَنَّهَا لَمَّا تُوُفِّيَ سَعْدُ بْنُ أَبِي وَقَّاصٍ أَرْسَلَ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم أَنْ يَمُرُّوا بِجَنَازَتِهِ فِي الْمَسْجِدِ فَيُصَلِّينَ عَلَيْهِ فَفَعَلُوا فَوُقِفَ بِهِ عَلَى حُجَرِهِنَّ يُصَلِّينَ عَلَيْهِ أُخْرِجَ بِهِ مِنْ بَابِ الْجَنَائِزِ الَّذِي كَانَ إِلَى الْمَقَاعِدِ فَبَلَغَهُنَّ أَنَّ النَّاسَ عَابُوا ذَلِكَ وَقَالُوا مَا كَانَتِ الْجَنَائِزُ يُدْخَلُ بِهَا الْمَسْجِدَ ‏.‏ فَبَلَغَ ذَلِكَ عَائِشَةَ فَقَالَتْ مَا أَسْرَعَ النَّاسَ إِلَى أَنْ يَعِيبُوا مَا لاَ عِلْمَ لَهُمْ بِهِ ‏.‏ عَابُوا عَلَيْنَا أَنْ يُمَرَّ بِجَنَازَةٍ فِي الْمَسْجِدِ وَمَا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى سُهَيْلِ ابْنِ بَيْضَاءَ إِلاَّ فِي جَوْفِ الْمَسْجِدِ ‏.‏\hadithno{2253}\hadithtrans{Abbad b. 'Abdullah b. Zubair reported on the authority of 'A'isha that when Sa'd b. Abu Waqqas died, the wives of the Messenger of Allah (ﷺ) sent message to bring his bier into the mosque so that they should offer prayer for him. They (the participants of the funeral) did accordingly, and it was placed in front of their apartments and they offered prayer for him. It was brought out of the door (known as) Bab al-Jana'iz which was towards the side of Maqa'id, and the news reached them (the wives of the Holy Prophet) that the people bad criticised this (i. e. offering of funeral prayer in the mosque) saying that it was not desirable to take the bier inside the mosque. This was conveyed to 'A'isha. She said:How hastily the people criticise that about which they know little. They criticise us for carrying the bier in the mosque. The Messenger of Allah (ﷺ) offered not the funeral prayer of Suhail b. Baida' but in the innermost part of the mosque}}
\hadithdefcmd{muslim}{2254}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ رَافِعٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، - يَعْنِي ابْنَ عُثْمَانَ - عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ بْنِ، عَبْدِ الرَّحْمَنِ أَنَّ عَائِشَةَ، لَمَّا تُوُفِّيَ سَعْدُ بْنُ أَبِي وَقَّاصٍ قَالَتِ ادْخُلُوا بِهِ الْمَسْجِدَ حَتَّى أُصَلِّيَ عَلَيْهِ ‏.‏ فَأُنْكِرَ ذَلِكَ عَلَيْهَا فَقَالَتْ وَاللَّهِ لَقَدْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى ابْنَىْ بَيْضَاءَ فِي الْمَسْجِدِ سُهَيْلٍ وَأَخِيهِ ‏.‏ قَالَ مُسْلِمٌ سُهَيْلُ بْنُ دَعْدٍ وَهُوَ ابْنُ الْبَيْضَاءِ أُمُّهُ بَيْضَاءُ ‏.‏\hadithno{2254}\hadithtrans{Abu Salama b. 'Abd al-Rahman reported on the authority ot 'A'isha that when Sa'd b. Abu Waqqas died she said:Bring it (the bier) into the mosque so that I offer prayer for him. But, this act of hers was disapproved. She said: By Allah, the Messenger of Allah (ﷺ) offered prayer in the mosque for the two sons of Baida', viz, for Suhail and his brother}}
\hadithdefcmd{muslim}{2255}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ شَرِيكٍ، - وَهُوَ ابْنُ أَبِي نَمِرٍ - عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم - كُلَّمَا كَانَ لَيْلَتُهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم - يَخْرُجُ مِنْ آخِرِ اللَّيْلِ إِلَى الْبَقِيعِ فَيَقُولُ ‏"‏ السَّلاَمُ عَلَيْكُمْ دَارَ قَوْمٍ مُؤْمِنِينَ وَأَتَاكُمْ مَا تُوعَدُونَ غَدًا مُؤَجَّلُونَ وَإِنَّا إِنْ شَاءَ اللَّهُ بِكُمْ لاَحِقُونَ اللَّهُمَّ اغْفِرْ لأَهْلِ بَقِيعِ الْغَرْقَدِ ‏"‏ ‏.‏ وَلَمْ يُقِمْ قُتَيْبَةُ قَوْلَهُ ‏"‏ وَأَتَاكُمْ ‏"‏ ‏.‏\hadithno{2255}\hadithtrans{A'isha reported (that whenever it was her turn for Allah's Messenger [may peace be upon him] to spend the night with her) he would go out towards the end of the night to al-Baqi' and say:Peace be upon you, abode of a people who are believers. What you were promised would come to you tomorrow, you receiving it after some delay; and God willing we shall join you. O Allah, grant forgiveness to the inhabitants of Baqi' al-Gharqad. Qutaiba did not mention his words:" would come to you}}
\hadithdefcmd{muslim}{2256}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرِ بْنِ الْمُطَّلِبِ، أَنَّهُ سَمِعَ مُحَمَّدَ بْنَ قَيْسٍ، يَقُولُ سَمِعْتُ عَائِشَةَ، تُحَدِّثُ فَقَالَتْ أَلاَ أُحَدِّثُكُمْ عَنِ النَّبِيِّ صلى الله عليه وسلم وَعَنِّي ‏.‏ قُلْنَا بَلَى ح. وَحَدَّثَنِي مَنْ، سَمِعَ حَجَّاجًا الأَعْوَرَ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَبْدُ اللَّهِ، - رَجُلٌ مِنْ قُرَيْشٍ - عَنْ مُحَمَّدِ بْنِ قَيْسِ بْنِ مَخْرَمَةَ، بْنِ الْمُطَّلِبِ أَنَّهُ قَالَ يَوْمًا أَلاَ أُحَدِّثُكُمْ عَنِّي وَعَنْ أُمِّي قَالَ فَظَنَنَّا أَنَّهُ يُرِيدُ أُمَّهُ الَّتِي وَلَدَتْهُ ‏.‏ قَالَ قَالَتْ عَائِشَةُ أَلاَ أُحَدِّثُكُمْ عَنِّي وَعَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قُلْنَا بَلَى ‏.‏ قَالَ قَالَتْ لَمَّا كَانَتْ لَيْلَتِيَ الَّتِي كَانَ النَّبِيُّ صلى الله عليه وسلم فِيهَا عِنْدِي انْقَلَبَ فَوَضَعَ رِدَاءَهُ وَخَلَعَ نَعْلَيْهِ فَوَضَعَهُمَا عِنْدَ رِجْلَيْهِ وَبَسَطَ طَرَفَ إِزَارِهِ عَلَى فِرَاشِهِ فَاضْطَجَعَ فَلَمْ يَلْبَثْ إِلاَّ رَيْثَمَا ظَنَّ أَنْ قَدْ رَقَدْتُ فَأَخَذَ رِدَاءَهُ رُوَيْدًا وَانْتَعَلَ رُوَيْدًا وَفَتَحَ الْبَابَ فَخَرَجَ ثُمَّ أَجَافَهُ رُوَيْدًا فَجَعَلْتُ دِرْعِي فِي رَأْسِي وَاخْتَمَرْتُ وَتَقَنَّعْتُ إِزَارِي ثُمَّ انْطَلَقْتُ عَلَى إِثْرِهِ حَتَّى جَاءَ الْبَقِيعَ فَقَامَ فَأَطَالَ الْقِيَامَ ثُمَّ رَفَعَ يَدَيْهِ ثَلاَثَ مَرَّاتٍ ثُمَّ انْحَرَفَ فَانْحَرَفْتُ فَأَسْرَعَ فَأَسْرَعْتُ فَهَرْوَلَ فَهَرْوَلْتُ فَأَحْضَرَ فَأَحْضَرْتُ فَسَبَقْتُهُ فَدَخَلْتُ فَلَيْسَ إِلاَّ أَنِ اضْطَجَعْتُ فَدَخَلَ فَقَالَ ‏"‏ مَا لَكِ يَا عَائِشُ حَشْيَا رَابِيَةً ‏"‏ ‏.‏ قَالَتْ قُلْتُ لاَ شَىْءَ ‏.‏ قَالَ ‏"‏ لَتُخْبِرِينِي أَوْ لَيُخْبِرَنِّي اللَّطِيفُ الْخَبِيرُ ‏"‏ ‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي ‏.‏ فَأَخْبَرْتُهُ قَالَ ‏"‏ فَأَنْتِ السَّوَادُ الَّذِي رَأَيْتُ أَمَامِي ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ فَلَهَدَنِي فِي صَدْرِي لَهْدَةً أَوْجَعَتْنِي ثُمَّ قَالَ ‏"‏ أَظَنَنْتِ أَنْ يَحِيفَ اللَّهُ عَلَيْكِ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَتْ مَهْمَا يَكْتُمِ النَّاسُ يَعْلَمْهُ اللَّهُ نَعَمْ ‏.‏ قَالَ ‏"‏ فَإِنَّ جِبْرِيلَ أَتَانِي حِينَ رَأَيْتِ فَنَادَانِي فَأَخْفَاهُ مِنْكِ فَأَجَبْتُهُ فَأَخْفَيْتُهُ مِنْكِ وَلَمْ يَكُنْ يَدْخُلُ عَلَيْكِ وَقَدْ وَضَعْتِ ثِيَابَكِ وَظَنَنْتُ أَنْ قَدْ رَقَدْتِ فَكَرِهْتُ أَنْ أُوقِظَكِ وَخَشِيتُ أَنْ تَسْتَوْحِشِي فَقَالَ إِنَّ رَبَّكَ يَأْمُرُكَ أَنْ تَأْتِيَ أَهْلَ الْبَقِيعِ فَتَسْتَغْفِرَ لَهُمْ ‏"‏ ‏.‏ قَالَتْ قُلْتُ كَيْفَ أَقُولُ لَهُمْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ قُولِي السَّلاَمُ عَلَى أَهْلِ الدِّيَارِ مِنَ الْمُؤْمِنِينَ وَالْمُسْلِمِينَ وَيَرْحَمُ اللَّهُ الْمُسْتَقْدِمِينَ مِنَّا وَالْمُسْتَأْخِرِينَ وَإِنَّا إِنْ شَاءَ اللَّهُ بِكُمْ لَلاَحِقُونَ ‏"‏ ‏.‏\hadithno{2256}\hadithtrans{Muhammad b. Qais said (to the people):Should I not narrate to you (a hadith of the Holy Prophet) on my authority and on the authority of my mother? We thought that he meant the mother who had given him birth. He (Muhammad b. Qais) then reported that it was 'A'isha who had narrated this: Should I not narrate to you about myself and about the Messenger of Allah (ﷺ)? We said: Yes. She said: When it was my turn for Allah's Messenger (ﷺ) to spend the night with me, he turned his side, put on his mantle and took off his shoes and placed them near his feet, and spread the corner of his shawl on his bed and then lay down till he thought that I had gone to sleep. He took hold of his mantle slowly and put on the shoes slowly, and opened the door and went out and then closed it lightly. I covered my head, put on my veil and tightened my waist wrapper, and then went out following his steps till he reached Baqi'. He stood there and he stood for a long time. He then lifted his hands three times, and then returned and I also returned. He hastened his steps and I also hastened my steps. He ran and I too ran. He came (to the house) and I also came (to the house). I, however, preceded him and I entered (the house), and as I lay down in the bed, he (the Holy Prophet) entered the (house), and said: Why is it, O 'A'isha, that you are out of breath? I said: There is nothing. He said: Tell me or the Subtle and the Aware would inform me. I said: Messenger of Allah, may my father and mother be ransom for you, and then I told him (the whole story). He said: Was it the darkness (of your shadow) that I saw in front of me? I said: Yes. He gave me a nudge on the chest which I felt, and then said: Did you think that Allah and His Apostle would deal unjustly with you? She said: Whatsoever the people conceal, Allah will know it. He said: Gabriel came to me when you saw me. He called me and he concealed it from you. I responded to his call, but I too concealed it from you (for he did not come to you), as you were not fully dressed. I thought that you had gone to sleep, and I did not like to awaken you, fearing that you may be frightened. He (Gabriel) said: Your Lord has commanded you to go to the inhabitants of Baqi' (to those lying in the graves) and beg pardon for them. I said: Messenger of Allah, how should I pray for them (How should I beg forgiveness for them)? He said: Say, Peace be upon the inhabitants of this city (graveyard) from among the Believers and the Muslims, and may Allah have mercy on those who have gone ahead of us, and those who come later on, and we shall, God willing, join you}}
\hadithdefcmd{muslim}{2257}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، الأَسَدِيُّ عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُهُمْ إِذَا خَرَجُوا إِلَى الْمَقَابِرِ فَكَانَ قَائِلُهُمْ يَقُولُ - فِي رِوَايَةِ أَبِي بَكْرٍ - السَّلاَمُ عَلَى أَهْلِ الدِّيَارِ - وَفِي رِوَايَةِ زُهَيْرٍ - السَّلاَمُ عَلَيْكُمْ أَهْلَ الدِّيَارِ مِنَ الْمُؤْمِنِينَ وَالْمُسْلِمِينَ وَإِنَّا إِنْ شَاءَ اللَّهُ لَلَاحِقُونَ أَسْأَلُ اللَّهَ لَنَا وَلَكُمْ الْعَافِيَةَ\hadithno{2257}\hadithtrans{Sulaiman b. Buraida narrated on the authority of his father that the Messenger of Allah (ﷺ) used to teach them when they went out to the graveyard. One of the narrators used to say this in the narration transmitted on the authority of Abu Bakr:" Peace be upon the inhabitants of the city (i. e. graveyard)." In the hadith transmitted by Zuhair (the words are):" Peace be upon you, the inhabitants of the city, among the believers, and Muslims, and God willing we shall join you. I beg of Allah peace for us and for you}}
\hadithdefcmd{muslim}{2258}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَمُحَمَّدُ بْنُ عَبَّادٍ، - وَاللَّفْظُ لِيَحْيَى - قَالاَ حَدَّثَنَا مَرْوَانُ، بْنُ مُعَاوِيَةَ عَنْ يَزِيدَ، - يَعْنِي ابْنَ كَيْسَانَ - عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْتَأْذَنْتُ رَبِّي أَنْ أَسْتَغْفِرَ لأُمِّي فَلَمْ يَأْذَنْ لِي وَاسْتَأْذَنْتُهُ أَنْ أَزُورَ قَبْرَهَا فَأَذِنَ لِي ‏"‏ ‏.‏\hadithno{2258}\hadithtrans{Abu Huraira reported Allah's Messenger, (ﷺ) as saying:I sought permission to beg forgiveness for my mother, but He did not grant it to me. I sought permission from Him to visit her grave, and He granted it (permission) to me}}
\hadithdefcmd{muslim}{2259}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ زَارَ النَّبِيُّ صلى الله عليه وسلم قَبْرَ أُمِّهِ فَبَكَى وَأَبْكَى مَنْ حَوْلَهُ فَقَالَ ‏ "‏ اسْتَأْذَنْتُ رَبِّي فِي أَنْ أَسْتَغْفِرَ لَهَا فَلَمْ يُؤْذَنْ لِي وَاسْتَأْذَنْتُهُ فِي أَنْ أَزُورَ قَبْرَهَا فَأُذِنَ لِي فَزُورُوا الْقُبُورَ فَإِنَّهَا تُذَكِّرُ الْمَوْتَ ‏"‏ ‏.‏\hadithno{2259}\hadithtrans{Abu Huraira reported:The Apostle of Allah (ﷺ) visited the grave of his mother and he wept, and moved others around him to tears, and said: I sought permission from my Lord to beg forgiveness for her but it was not granted to me, and I sought permission to visit her grave and it was granted to me so visit the graves, for that makes you mindful of death}}
\hadithdefcmd{muslim}{2260}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لأَبِي بَكْرٍ وَابْنِ نُمَيْرٍ - قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِي سِنَانٍ، - وَهُوَ ضِرَارُ بْنُ مُرَّةَ - عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَهَيْتُكُمْ عَنْ زِيَارَةِ الْقُبُورِ فَزُورُوهَا وَنَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِيِّ فَوْقَ ثَلاَثٍ فَأَمْسِكُوا مَا بَدَا لَكُمْ وَنَهَيْتُكُمْ عَنِ النَّبِيذِ إِلاَّ فِي سِقَاءٍ فَاشْرَبُوا فِي الأَسْقِيَةِ كُلِّهَا وَلاَ تَشْرَبُوا مُسْكِرًا ‏"‏ ‏.‏ قَالَ ابْنُ نُمَيْرٍ فِي رِوَايَتِهِ عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ عَنْ أَبِيهِ ‏.‏\hadithno{2260}\hadithtrans{Ibn Buraida reported on the authority of his father that the Messenger of Allah (ﷺ) said:I forbade you to visit graves, but you may now visit them; I forbade you to eat the flesh of sacrificial animals after three days, but you way now keep it as along as you feel inclined; and I forbade you nabidh except in a water-skin, you may drink it from all kinds of water-skins, but you must not drink anything intoxicating}}
\hadithdefcmd{muslim}{2261}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ زُبَيْدٍ الْيَامِيِّ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنِ ابْنِ بُرَيْدَةَ، أُرَاهُ عَنْ أَبِيهِ، - الشَّكُّ مِنْ أَبِي خَيْثَمَةَ - عَنِ النَّبِيِّ صلى الله عليه وسلم ح . وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا قَبِيصَةُ بْنُ عُقْبَةَ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ، بْنِ مَرْثَدٍ عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح . وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ عَبْدِ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ عَطَاءٍ الْخُرَاسَانِيِّ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم كُلُّهُمْ بِمَعْنَى حَدِيثِ أَبِي سِنَانٍ ‏.‏\hadithno{2261}\hadithtrans{This hadith has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{2262}{حَدَّثَنَا عَوْنُ بْنُ سَلاَّمٍ الْكُوفِيُّ، أَخْبَرَنَا زُهَيْرٌ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِرَجُلٍ قَتَلَ نَفْسَهُ بِمَشَاقِصَ فَلَمْ يُصَلِّ عَلَيْهِ ‏.‏\hadithno{2262}\hadithtrans{Jabir b. Samura reported:(The dead body) of a person who had killed himself with a broad-headed arrow was brought before the Messenger of Allah (ﷺ), but he did not offer prayers for him}}
